@@ -12,6 +12,7 @@ logger = logging.getLogger(__name__)
 class BaseDataType(object):
     def __init__(self, model=None):
         self.datatype_model = model
+        self.datatype_name = model.datatype if model else None
 
     def validate(self, value, row_number=None, source=None, node=None, nodeid=None, strict=False, **kwargs):
         """
@@ -35,7 +36,7 @@ class BaseDataType(object):
         source_info = "{0} {1}".format(source, row_number) if row_number else ""
         error_message = {
             "type": "ERROR",
-            "message": _("{0} error, {1} {2} - {3}. Unable to save.").format(self.datatype_model.datatype, value, source_info, message),
+            "message": _("{0} error, {1} {2} - {3}. Unable to save.").format(self.datatype_name, value, source_info, message),
         }
         return error_message
 
@@ -82,12 +83,6 @@ class BaseDataType(object):
         """
         return None
 
-    def process_mobile_data(self, tile, node, db, couch_doc, node_value):
-        """
-        Transforms data from a mobile device to an Arches friendly format
-        """
-        return None
-
     def get_map_layer(self, node=None):
         """
         Gets the array of map layers to add to the map for a given node
@@ -208,7 +203,7 @@ class BaseDataType(object):
             logger.exception(_("Tile has no authoritative or provisional data"))
 
 
-    def get_display_value(self, tile, node):
+    def get_display_value(self, tile, node, **kwargs):
         """
         Returns a list of concept values for a given node
         """
@@ -222,7 +217,7 @@ class BaseDataType(object):
 
     def get_search_terms(self, nodevalue, nodeid=None):
         """
-        Returns a nodevalue if it qualifies as a search term
+        Returns an array of arches.app.search_term.SearchTerm objects
         """
         return []
 
@@ -289,12 +284,6 @@ class BaseDataType(object):
             base_query.must(null_query)
         query.must(base_query)
 
-    def handle_request(self, current_tile, request, node):
-        """
-        Updates files
-        """
-        pass
-
     def pre_tile_save(self, tile, nodeid):
         """
         Called during tile.save operation but before the tile is actually saved to the database
@@ -302,6 +291,19 @@ class BaseDataType(object):
         """
         pass
 
+    def get_default_language_value_from_localized_node(self, tile, nodeid):
+        """
+        If value is internationalized, return only the first value in the i18n object
+        """
+        return tile.data[str(nodeid)]
+
+    def post_tile_save(self, tile, nodeid, request):
+        """
+        Called after the tile is saved to the database
+
+        """
+        pass
+
     def post_tile_delete(self, tile, nodeid, index=True):
         """
         Called following the tile.delete operation
@@ -309,6 +311,12 @@ class BaseDataType(object):
         """
         pass
 
+    def is_multilingual_rdf(self, rdf):
+        """
+        Determines if the rdf snippet contains multiple languages that can be processed by a given datatype
+        """
+        return False
+
     def is_a_literal_in_rdf(self):
         """
         Convenience method to determine whether or not this datatype's `to_rdf` method will express
@@ -434,3 +442,22 @@ class BaseDataType(object):
         ret = {"@display_value": self.get_display_value(tile, node)}
         ret.update(kwargs)
         return ret
+
+    def has_multicolumn_data(self):
+        """
+        Used primarily for csv exports - true if data
+        for a node can span multiple columns
+        """
+        return False
+
+    def get_column_header(self, node, **kwargs):
+        """
+        Returns a CSV column header or headers for a given node ID of this type
+        """
+        return node["file_field_name"]
+
+    def pre_structure_tile_data(self, tile, nodeid, **kwargs):
+        """
+        Adds properties to a tile necessary for some clients, but not essential to the tile
+        """
+        pass
