@@ -28,6 +28,7 @@ class BaseConceptDataType(BaseDataType):
         super(BaseConceptDataType, self).__init__(model=model)
         self.value_lookup = {}
         self.collection_lookup = {}
+        self.collection_by_node_lookup = {}
 
     def lookup_label(self, label, collectionid):
         ret = label
@@ -37,7 +38,16 @@ class BaseConceptDataType(BaseDataType):
                 ret = concept[2]
         return ret
 
-    def lookup_labelid_from_label(self, value, collectionid):
+    def lookup_labelid_from_label(self, value, config):
+        if "rdmCollection" in config:
+            collectionid = config["rdmCollection"]
+        elif "nodeid" in config:
+            nodeid = config["nodeid"]
+            if nodeid in self.collection_by_node_lookup:
+                collectionid = self.collection_by_node_lookup[nodeid]
+            else:
+                collectionid = models.Node.objects.get(nodeid=nodeid).config["rdmCollection"]
+                self.collection_by_node_lookup[nodeid] = collectionid
         try:
             result = self.lookup_label(value, collectionid)
         except KeyError:
@@ -155,8 +165,7 @@ class ConceptDataType(BaseConceptDataType):
             uuid.UUID(stripped)
             value = stripped
         except ValueError:
-            if "rdmCollection" in kwargs:
-                value = self.lookup_labelid_from_label(value, kwargs["rdmCollection"])
+            value = self.lookup_labelid_from_label(value, kwargs)
         return value
 
     def transform_export_values(self, value, *args, **kwargs):
@@ -166,7 +175,7 @@ class ConceptDataType(BaseConceptDataType):
     def get_pref_label(self, nodevalue, lang="en-US"):
         return get_preflabel_from_valueid(nodevalue, lang)["value"]
 
-    def get_display_value(self, tile, node):
+    def get_display_value(self, tile, node, **kwargs):
         data = self.get_tile_data(tile)
         if data[str(node.nodeid)] is None or data[str(node.nodeid)].strip() == "":
             return ""
@@ -267,7 +276,6 @@ class ConceptDataType(BaseConceptDataType):
             # No concept_id means not in RDM at all
             return None
 
-
     def ignore_keys(self):
         return ["http://www.w3.org/2000/01/rdf-schema#label http://www.w3.org/2000/01/rdf-schema#Literal"]
 
@@ -293,8 +301,7 @@ class ConceptListDataType(BaseConceptDataType):
                     uuid.UUID(stripped)
                     ret.append(stripped)
                 except ValueError:
-                    if "rdmCollection" in kwargs:
-                        ret.append(self.lookup_labelid_from_label(v, kwargs["rdmCollection"]))
+                    ret.append(self.lookup_labelid_from_label(v, kwargs))
         return ret
 
     def transform_export_values(self, value, *args, **kwargs):
@@ -304,7 +311,7 @@ class ConceptListDataType(BaseConceptDataType):
             new_values.append(new_val)
         return ",".join(new_values)
 
-    def get_display_value(self, tile, node):
+    def get_display_value(self, tile, node, **kwargs):
         new_values = []
         data = self.get_tile_data(tile)
         if data[str(node.nodeid)]:
