@@ -35,12 +35,13 @@ class ImportSingleCsv(BaseImportModule):
         self.blank_tile_lookup = {}
 
     def get_graphs(self, request):
+        graph_name_i18n = "name__" + settings.LANGUAGE_CODE
         graphs = (
             GraphModel.objects.all()
             .exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
             .exclude(isresource=False)
-            .exclude(isactive=False)
-            .order_by(Lower("name"))
+            .exclude(publication_id__isnull=True)
+            .order_by(graph_name_i18n)
         )
         return {"success": True, "data": graphs}
 
@@ -159,18 +160,18 @@ class ImportSingleCsv(BaseImportModule):
             if task_management.check_if_celery_available():
                 logger.info(_("Delegating load to Celery task"))
                 tasks.load_single_csv.apply_async(
-                    (self.loadid, graphid, has_headers, fieldnames, csv_file_name, id_label),
+                    (self.userid, self.loadid, graphid, has_headers, fieldnames, csv_file_name, id_label),
                 )
                 result = _("delegated_to_celery")
                 return {"success": True, "data": result}
             else:
-                err = _("Celery appears not to be running. You need to have celery running in order to import a large csv.")
+                err = _("Unable to perform this operation because Celery does not appear to be running. Please contact your administrator.")
                 with connection.cursor() as cursor:
                     cursor.execute(
                         """UPDATE load_event SET status = %s, load_end_time = %s WHERE loadid = %s""",
                         ("failed", datetime.now(), self.loadid),
                     )
-                return {"success": False, "data": err}
+                return {"success": False, "data": {"title": _("Error"), "message": err}}
 
         else:
             response = self.run_load_task(self.loadid, graphid, has_headers, fieldnames, csv_file_name, id_label)
