@@ -1,5 +1,6 @@
 import logging
 import uuid
+from arches.app.utils.betterJSONSerializer import JSONSerializer
 from arches.app.functions.base import BaseFunction
 from arches.app.models import models
 from arches.app.datatypes.datatypes import DataTypeFactory
@@ -34,37 +35,31 @@ class PrimaryDescriptorsFunction(AbstractPrimaryDescriptorsFunction):
         """
 
         datatype_factory = None
+        language = None
         try:
-            if (
-                "nodegroup_id" in config
-                and config["nodegroup_id"] != ""
-                and config["nodegroup_id"] is not None
-            ):
-                tiles = models.TileModel.objects.filter(
-                    nodegroup_id=uuid.UUID(config["nodegroup_id"]), sortorder=0
-                ).filter(resourceinstance_id=resource.resourceinstanceid)
+            if "nodegroup_id" in config and config["nodegroup_id"] != "" and config["nodegroup_id"] is not None:
+                tiles = models.TileModel.objects.filter(nodegroup_id=uuid.UUID(config["nodegroup_id"]), sortorder=0).filter(
+                    resourceinstance_id=resource.resourceinstanceid
+                )
                 if len(tiles) == 0:
-                    tiles = models.TileModel.objects.filter(
-                        nodegroup_id=uuid.UUID(config["nodegroup_id"])
-                    ).filter(resourceinstance_id=resource.resourceinstanceid)
+                    tiles = models.TileModel.objects.filter(nodegroup_id=uuid.UUID(config["nodegroup_id"])).filter(
+                        resourceinstance_id=resource.resourceinstanceid
+                    )
                 for tile in tiles:
-                    for node in models.Node.objects.filter(
-                        nodegroup_id=uuid.UUID(config["nodegroup_id"])
-                    ):
+                    for node in models.Node.objects.filter(nodegroup_id=uuid.UUID(config["nodegroup_id"])):
                         data = {}
                         if len(list(tile.data.keys())) > 0:
                             data = tile.data
-                        elif (
-                            tile.provisionaledits is not None
-                            and len(list(tile.provisionaledits.keys())) == 1
-                        ):
+                        elif tile.provisionaledits is not None and len(list(tile.provisionaledits.keys())) == 1:
                             userid = list(tile.provisionaledits.keys())[0]
                             data = tile.provisionaledits[userid]["value"]
                         if str(node.nodeid) in data:
                             if not datatype_factory:
                                 datatype_factory = DataTypeFactory()
                             datatype = datatype_factory.get_instance(node.datatype)
-                            value = datatype.get_display_value(tile, node)
+                            if context is not None and "language" in context:
+                                language = context["language"]
+                            value = datatype.get_display_value(tile, node, language=language)
                             if value is None:
                                 value = ""
                             config["string_template"] = config["string_template"].replace("<%s>" % node.name, str(value))
