@@ -1,8 +1,9 @@
 define([
     'jquery',
     'underscore',
-    'knockout'
-], function ($, _, ko) {
+    'knockout',
+    'arches',
+], function($, _, ko, arches) {
     /**
     * A knockout.js binding for the "ckeditor" rich text editor widget
     * - pass options to ckeditor using the following syntax in the knockout
@@ -13,16 +14,36 @@ define([
     * @name ckeditor
     */
 
-    const initialize = function (element, valueAccessor, allBindings) {
+    const initialize = function(element, valueAccessor, allBindings) {
         var modelValue = valueAccessor();
         var value = ko.utils.unwrapObservable(valueAccessor());
+        const language = allBindings.get('language') || ko.observable(arches.activeLanguage);
+        const direction = allBindings.get('direction') || ko.observable(arches.activeLanguageDir);
         var $element = $(element);
-        var options = {};
+        var options = {bodyId: 'ckeditor'};
+        const languageList = [];
+        
+        for(const lang of Object.keys(arches.languages)){
+            languageList.push(`${lang}:${arches.languages[lang]}`);
+        }
+        /* eslint-disable no-undef */
+        CKEDITOR.config.language_list = languageList;
+        CKEDITOR.config.language = language();
+        CKEDITOR.config.contentsLangDirection = direction();
+
+        direction.subscribe(newValue => {
+            CKEDITOR.config.contentsLangDirection = newValue;
+            CKEDITOR.replace('ckeditor', CKEDITOR.config);
+        });
+
+        language.subscribe(newValue => {
+            CKEDITOR.config.language = newValue;
+        });
 
         if (allBindings.has('ckeditorOptions')){
             var opts = allBindings.get('ckeditorOptions');
             options = (typeof opts === 'object') ? opts : {};
-        };
+        }
 
         // Set initial value and create the CKEditor
         $element.html(value);
@@ -34,9 +55,8 @@ define([
             }
         });
 
-
         // bind to change events and link it to the observable
-        var onChange = function (e) {
+        var onChange = function(e) {
             var self = this;
 
             if (ko.isWriteableObservable(self)) {
@@ -48,8 +68,13 @@ define([
             return true;
         };
         editor.on('change', onChange, modelValue, element);
+        editor.on('afterCommandExec', (event => {
+            if(event.data.name == 'language'){
+                language(event.data.commandData);
+            }
+        }), modelValue, element);
 
-        modelValue.subscribe(function(newValue){
+        modelValue.subscribe(function(value){
             var self = this;
             var $element = $(element);
             var newValue = ko.utils.unwrapObservable(valueAccessor());
@@ -60,11 +85,10 @@ define([
                 editor.setData(newValue);
                 editor.on('change', onChange, modelValue, element);
             }
-        }, this)
-
+        }, this);
 
         // Handle disposal if KO removes an editor through template binding
-        ko.utils.domNodeDisposal.addDisposeCallback(element, function () {
+        ko.utils.domNodeDisposal.addDisposeCallback(element, function() {
             editor.updateElement();
             editor.destroy();
         });
@@ -72,11 +96,12 @@ define([
 
     ko.bindingHandlers.ckeditor = {
         init: (element, valueAccessor, allBindings) => {
-            require(['ckeditor-jquery', 'ckeditor'], () => {
+            window.jQuery = $;
+            require(['ckeditor', 'ckeditor-jquery'], () => {
                 initialize(element, valueAccessor, allBindings);
-            })
+            });
         }
     };
 
     return ko.bindingHandlers.ckeditor;
-});
+});
\ No newline at end of file
