@@ -1,4 +1,4 @@
-define(['arches', 'models/abstract'], function(arches, AbstractModel) {
+define(['arches', 'models/abstract', 'utils/set-csrf-token'], function(arches, AbstractModel) {
     return AbstractModel.extend({
         url: arches.urls.tile,
 
