@@ -1,13 +1,13 @@
 define([
     'jquery',
-    'arches',
     'knockout',
     'underscore',
+    'arches',
     'dropzone',
     'uuid',
     'viewmodels/widget',
     'bindings/dropzone'
-], function($, arches, ko, _, Dropzone, uuid, WidgetViewModel) {
+], function($, ko, _, arches, Dropzone, uuid, WidgetViewModel) {
     /**
      * A viewmodel used for domain widgets
      *
@@ -29,7 +29,7 @@ define([
 
 
         if (this.form) {
-            this.form.on('after-update', function(req, tile) {
+            $(this.form).on('after-update', function(req, tile) {
                 var hasdata = _.filter(tile.data, function(val, key) {
                     val = ko.unwrap(val);
                     if (val) {
