@@ -1,17 +1,19 @@
 define([
     'jquery',
-    'arches',
     'knockout',
     'knockout-mapping',
     'geojson-extent',
+    'arches',
     'viewmodels/card-component',
     'viewmodels/map-editor',
     'viewmodels/map-filter',
     'views/components/cards/select-related-feature-layers',
-    'text!templates/views/components/cards/related-resources-map-popup.htm'
-], function($, arches, ko, koMapping, geojsonExtent, CardComponentViewModel, MapEditorViewModel, MapFilterViewModel, selectFeatureLayersFactory, popupTemplate) {
+    'templates/views/components/cards/related-resources-map.htm',
+    'templates/views/components/cards/related-resources-map-popup.htm',
+], function($, ko, koMapping, geojsonExtent, arches, CardComponentViewModel, MapEditorViewModel, MapFilterViewModel, selectFeatureLayersFactory, relatedResourcesMapTemplate, relatedResourcesMapPopupTemplate) {
     var viewModel = function(params) {
         var self = this;
+         
 
         this.widgets = [];
         params.configKeys = [
@@ -34,9 +36,9 @@ define([
         ];
         CardComponentViewModel.apply(this, [params]);
         var selectLayerConfig = {};
-        selectLayerConfig.defaultcolor = this.defaultcolor()
-        selectLayerConfig.selectioncolor = this.selectioncolor()
-        selectLayerConfig.hovercolor = this.hovercolor()
+        selectLayerConfig.defaultcolor = this.defaultcolor();
+        selectLayerConfig.selectioncolor = this.selectioncolor();
+        selectLayerConfig.hovercolor = this.hovercolor();
         selectLayerConfig.colorpalette = typeof this.colorpalette() === 'string' ? this.colorpalette().split(",") : this.colorpalette();
         selectLayerConfig.fillopacity = Number(this.fillopacity());
         selectLayerConfig.overviewzoom = Number(this.overviewzoom());
@@ -62,7 +64,6 @@ define([
                 var sourceUrl = new window.URL(arches.mapSources[self.selectRelatedSource()].data, window.location.origin);
                 var nodes = sourceUrl.searchParams.get('nodeids');
                 var node = sourceUrl.searchParams.get('nodeid');
-                var nodeids = [];
                 if (node) {
                     nodeids.push(node);
                 }
@@ -77,14 +78,14 @@ define([
             set/get logic to ensure all data values are equal between parent and children
         */
 
-       this.basemap = ko.observable();
-       this.overlayConfigs = ko.observable();
-       this.centerX = ko.observable();
-       this.centerY = ko.observable();
+        this.basemap = ko.observable();
+        this.overlayConfigs = ko.observable();
+        this.centerX = ko.observable();
+        this.centerY = ko.observable();
 
-       for (var widget of self.widgets) {
+        for (var widget of self.widgets) {
             if (widget.config.basemap) {
-               self.basemap(widget.config.basemap());
+                self.basemap(widget.config.basemap());
             }
             if (widget.config.overlayConfigs) {
                 self.overlayConfigs(widget.config.overlayConfigs());
@@ -100,28 +101,28 @@ define([
         this.basemap.subscribe(function(map) {
             for (var widget of self.widgets) {
                 if (widget.config.basemap) {
-                    widget.config.basemap(map)
+                    widget.config.basemap(map);
                 }
             }
         });
         this.overlayConfigs.subscribe(function(configs) {
             for (var widget of self.widgets) {
                 if (widget.config.overlayConfigs) {
-                    widget.config.overlayConfigs(configs)
+                    widget.config.overlayConfigs(configs);
                 }
             }
         });
         this.centerX.subscribe(function(x) {
             for (var widget of self.widgets) {
                 if (widget.config.centerX) {
-                    widget.config.centerX(x)
+                    widget.config.centerX(x);
                 }
             }
         });
         this.centerY.subscribe(function(y) {
             for (var widget of self.widgets) {
                 if (widget.config.centerY) {
-                    widget.config.centerY(y)
+                    widget.config.centerY(y);
                 }
             }
         });
@@ -132,7 +133,7 @@ define([
 
             for (var widget of self.widgets) {
                 if (widget.config.zoom) {
-                    widget.config.zoom(zoom)
+                    widget.config.zoom(zoom);
                 }
             }
         });
@@ -150,14 +151,14 @@ define([
         this.nodeDetails = ko.observableArray();
         this.nodeids.forEach(function(nodeid) {
             fetch(arches.urls.api_nodes(nodeid))
-              .then(response => response.json())
-              .then(data => {
-                self.nodeDetails.push(data[0]);
-              })
-              .catch((error) => {
-                console.error('Error:', error);
-              });
-        })
+                .then(response => response.json())
+                .then(data => {
+                    self.nodeDetails.push(data[0]);
+                })
+                .catch((error) => {
+                    console.error('Error:', error);
+                });
+        });
         var parsedNodeIds = JSON.parse(JSON.stringify(this.nodeids));
         var firstNode = parsedNodeIds.length > 0 ? [parsedNodeIds[0]] : [];
         this.filterNodeIds = ko.observableArray(firstNode);
@@ -197,8 +198,8 @@ define([
                 }
             });
             return tileResourceIds
-                .map(function(resourceid){return self.relatedResourceDetails[resourceid]})
-                .filter(function(val){return val !== undefined});
+                .map(function(resourceid){return self.relatedResourceDetails[resourceid];})
+                .filter(function(val){return val !== undefined;});
         });
 
         this.showRelatedQuery = ko.observable(false);
@@ -243,7 +244,7 @@ define([
         var selectFeatureLayers = selectFeatureLayersFactory(selectRelatedSource, selectRelatedSourceLayer, selectedResourceIds(), true, null, this.nodeids, this.filterNodeIds(), self.hoverId(), selectLayerConfig);
         var sources = [];
         for (var sourceName in arches.mapSources) {
-            if (arches.mapSources.hasOwnProperty(sourceName)) {
+            if (Object.prototype.hasOwnProperty.call(arches.mapSources, sourceName)) {
                 sources.push(sourceName);
             }
         }
@@ -278,7 +279,6 @@ define([
 
         params.fitBounds = resourceBounds;
         MapEditorViewModel.apply(this, [params]);
-        this.popupTemplate = popupTemplate;
 
         this.relateResource = function(resourceData, widget) {
             var id = widget.node_id();
@@ -288,7 +288,7 @@ define([
                 graphid: ko.unwrap(resourceData.graphid),
                 displayname: ko.unwrap(resourceData.displayname),
                 resourceinstanceid: ko.unwrap(resourceData.resourceinstanceid)
-            }
+            };
             zoomToData = false;
             var graphconfig = widget.node.config.graphs().find(function(graph){return graph.graphid === ko.unwrap(resourceData.graphid);});
             var val = [{
@@ -314,7 +314,7 @@ define([
         this.unrelateResource = function(resourceData, widget) {
             var id = widget.node_id();
             var resourceinstanceid = ko.unwrap(resourceData.resourceinstanceid);
-            var related = resourceData.mapCard.tile.data[id]()
+            var related = resourceData.mapCard.tile.data[id]();
             for( var i = 0; i < related.length; i++){ 
                 if ( ko.unwrap(related[i].resourceId) === resourceinstanceid) { 
                     related.splice(i, 1); 
@@ -409,7 +409,7 @@ define([
                     var feature;
                     if (features.length && features[0].properties.resourceinstanceid) {
                         feature = features[0].properties.resourceinstanceid;
-                        if (self.relatedResources().filter(function(val){return val.resourceinstanceid === feature}).length) {
+                        if (self.relatedResources().filter(function(val){return val.resourceinstanceid === feature;}).length) {
                             self.hoverId(feature);
                         }
                     } else {
@@ -419,11 +419,10 @@ define([
             }
         });
     };
+
     ko.components.register('related-resources-map-card', {
         viewModel: viewModel,
-        template: {
-            require: 'text!templates/views/components/cards/related-resources-map.htm'
-        }
+        template: relatedResourcesMapTemplate,
     });
     return viewModel;
 });
