@@ -1,17 +1,15 @@
 define([
     'jquery',
     'underscore',
-    'arches',
     'knockout',
     'viewmodels/map',
+    'templates/views/components/map.htm',
     'bindings/mapbox-gl',
     'bindings/sortable'
-], function($, _, arches, ko, MapViewModel) {
+], function($, _, ko, MapViewModel, mapTemplate) {
     ko.components.register('arches-map', {
         viewModel: MapViewModel,
-        template: {
-            require: 'text!templates/views/components/map.htm'
-        }
+        template: mapTemplate,
     });
     return MapViewModel;
 });
