@@ -1,8 +1,9 @@
 define([
     'knockout',
     'viewmodels/concept-widget',
-    'plugins/knockout-select2'
-], function(ko, ConceptWidgetViewModel) {
+    'templates/views/components/widgets/radio.htm',
+    'plugins/knockout-select2',
+], function(ko, ConceptWidgetViewModel, conceptRadioTemplate) {
     /**
      * registers a select-widget component for use in forms
      * @function external:"ko.components".select-widget
@@ -13,14 +14,15 @@ define([
      * @param {string} params.config.placeholder - default text to show in the select input
      * @param {string} params.config.options -
      */
-    return ko.components.register('concept-radio-widget', {
-        viewModel: function(params) {
-            params.configKeys = ['defaultValue'];
 
-            ConceptWidgetViewModel.apply(this, [params]);
-        },
-        template: {
-            require: 'text!widget-templates/radio'
-        }
+    const viewModel = function(params) {
+        params.configKeys = ['defaultValue'];
+         
+        ConceptWidgetViewModel.apply(this, [params]);
+    };
+
+    return ko.components.register('concept-radio-widget', {
+        viewModel: viewModel,
+        template: conceptRadioTemplate,
     });
 });
