@@ -1,7 +1,8 @@
 define([
     'knockout',
-    'viewmodels/domain-widget'
-], function(ko, DomainWidgetViewModel) {
+    'viewmodels/domain-widget',
+    'templates/views/components/widgets/radio.htm',
+], function(ko, DomainWidgetViewModel, radioTemplate) {
     /**
      * registers a select-widget component for use in forms
      * @function external:"ko.components".select-widget
@@ -12,13 +13,15 @@ define([
      * @param {string} params.config.placeholder - default text to show in the select input
      * @param {string} params.config.options -
      */
+
+    const viewModel = function(params) {
+         
+        params.configKeys = ['defaultValue'];
+        DomainWidgetViewModel.apply(this, [params]);
+    };
+
     return ko.components.register('domain-radio-widget', {
-        viewModel: function(params) {
-            params.configKeys = ['defaultValue'];
-            DomainWidgetViewModel.apply(this, [params]);
-        },
-        template: {
-            require: 'text!widget-templates/radio'
-        }
+        viewModel: viewModel,
+        template: radioTemplate,
     });
 });
