@@ -1,5 +1,5 @@
-define(['knockout', 'turf', 'arches'], function(ko, turf, arches) {
-    return function (searchAggregations) {
+define(['knockout', 'turf', 'arches', 'underscore'], function(ko, turf, arches, _) {
+    return function(searchAggregations) {
         var cellWidth = arches.hexBinSize;
         var units = 'kilometers';
         var hexGrid = turf.hexGrid(arches.hexBinBounds, cellWidth, units);
