@@ -3,6 +3,10 @@ define([
     'underscore',
     'knockout',
     'knockout-mapping',
+    'arches',
+    'report-templates',
+    'view-data',
+    'views/graph-designer-data',
     'views/base-manager',
     'viewmodels/alert',
     'viewmodels/alert-json',
@@ -13,19 +17,17 @@ define([
     'views/graph/graph-manager/branch-list',
     'views/graph/graph-designer/card-tree',
     'views/graph/permission-designer',
-    'graph-designer-data',
-    'arches',
     'viewmodels/graph-settings',
     'viewmodels/card',
-    'view-data',
-    'report-templates',
     'bindings/resizable-sidepanel',
-    'datatype-config-components',
-    'views/components/simple-switch'
-], function($, _, ko, koMapping, BaseManagerView, AlertViewModel, JsonErrorAlertViewModel, GraphModel, ReportModel, GraphTree, NodeFormView, BranchListView, CardTreeViewModel, PermissionDesigner, data, arches, GraphSettingsViewModel, CardViewModel, viewData, reportLookup) {
+    'views/components/simple-switch',
+    'utils/set-csrf-token',
+    'datatype-config-components'
+], function($, _, ko, koMapping, arches, reportLookup, viewData, data, BaseManagerView, AlertViewModel, JsonErrorAlertViewModel, GraphModel, ReportModel, GraphTree, NodeFormView, BranchListView, CardTreeViewModel, PermissionDesigner, GraphSettingsViewModel, CardViewModel) {
     var GraphDesignerView = BaseManagerView.extend({
         initialize: function(options) {
             var viewModel = options.viewModel;
+
             viewModel.graphid = ko.observable(data.graphid);
             viewModel.activeTab = ko.observable('graph');
             viewModel.viewState = ko.observable('design');
@@ -36,6 +38,34 @@ define([
             viewModel.ontologyClasses = ko.observable(data['ontologyClasses']);
             viewModel.cardComponents = data.cardComponents;
             viewModel.appliedFunctions = ko.observable(data['appliedFunctions']);
+            viewModel.activeLanguageDir = ko.observable(arches.activeLanguageDir);
+            viewModel.isGraphPublished = ko.observable(ko.unwrap(data['graph'].publication_id));
+            viewModel.graphPublicationNotes = ko.observable();
+            viewModel.shouldShowGraphPublishButtons = ko.pureComputed(function() {
+                var shouldShowGraphPublishButtons = true;
+
+                if (viewModel.dirty()) {
+                    shouldShowGraphPublishButtons = false;
+                }
+                else if (viewModel.graphSettingsViewModel && viewModel.graphSettingsViewModel.dirty()) {
+                    shouldShowGraphPublishButtons = false;
+                }
+                else if (viewModel.selectedNode() && viewModel.selectedNode().dirty() && viewModel.selectedNode().istopnode == false) {
+                    shouldShowGraphPublishButtons = false;
+                }
+                else if (ko.unwrap(viewModel.cardTree.selection)) {
+                    var selection = ko.unwrap(viewModel.cardTree.selection);
+
+                    if (selection.model && selection.model.dirty()) {
+                        shouldShowGraphPublishButtons = false;
+                    }
+                    else if (selection.card && selection.card.dirty()) {
+                        shouldShowGraphPublishButtons = false;
+                    }
+                }
+                
+                return shouldShowGraphPublishButtons;
+            });
             viewModel.primaryDescriptorFunction = ko.observable(data['primaryDescriptorFunction']);
 
             var resources = ko.utils.arrayFilter(viewData.graphs, function(graph) {
@@ -72,24 +102,76 @@ define([
                 window.open(arches.urls.export_mapping_file(viewModel.graph.graphid()), '_blank');
             };
 
-            viewModel.deleteGraph = function() {
-                viewModel.alert(new AlertViewModel('ep-alert-red', arches.confirmGraphDelete.title, arches.confirmGraphDelete.text, function() {
-                    return;
-                }, function(){
-                    viewModel.loading(true);
-                    $.ajax({
-                        type: "DELETE",
-                        url: arches.urls.delete_graph(viewModel.graph.graphid()),
-                        complete: function(response, status) {
-                            viewModel.loading(false);
-                            if (status === 'success') {
-                                window.location = arches.urls.graph;
-                            } else {
-                                viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
-                            }
+            viewModel.shouldShowPublishModal = ko.observable(false);
+
+            viewModel.displayUnpublishWarning = function() {
+                viewModel.alert(new AlertViewModel('ep-alert-red', 'Unpublish the graph?', 'This will make the graph inaccessible to other users.', function() {}, viewModel.unpublishGraph));
+            };
+            viewModel.publishGraph = function() {
+                viewModel.loading(true);
+
+                $.ajax({
+                    type: "POST",
+                    data: JSON.stringify({'notes': viewModel.graphPublicationNotes()}),
+                    url: arches.urls.publish_graph(viewModel.graph.graphid()),
+                    complete: function(response, status) {
+                        if (status === 'success') {
+                            viewModel.isGraphPublished(true);
+                            viewModel.alert(new AlertViewModel('ep-alert-blue', response.responseJSON.title, response.responseJSON.message));
                         }
-                    });
-                }));
+                        else {
+                            viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
+                        }
+                        
+                        viewModel.graphPublicationNotes(null);
+                        viewModel.shouldShowPublishModal(false);
+                        viewModel.loading(false);
+                    }
+                });
+            };
+            viewModel.unpublishGraph = function() {
+                viewModel.loading(true);
+
+                $.ajax({
+                    type: "POST",
+                    url: arches.urls.unpublish_graph(viewModel.graph.graphid()),
+                    complete: function(response, status) {
+                        if (status === 'success') {
+                            viewModel.isGraphPublished(false);
+                        }
+                        else {
+                            viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
+                        }
+
+                        viewModel.shouldShowPublishModal(false);
+                        viewModel.loading(false);
+                    }
+                });
+            };
+
+            viewModel.deleteGraph = function() {
+                viewModel.alert(new AlertViewModel(
+                    'ep-alert-red', 
+                    arches.translations.confirmGraphDelete.title, 
+                    arches.translations.confirmGraphDelete.text,
+                    function() {
+                        return;
+                    }, function(){
+                        viewModel.loading(true);
+                        $.ajax({
+                            type: "DELETE",
+                            url: arches.urls.delete_graph(viewModel.graph.graphid()),
+                            complete: function(response, status) {
+                                viewModel.loading(false);
+                                if (status === 'success') {
+                                    window.location = arches.urls.graph;
+                                } else {
+                                    viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
+                                }
+                            }
+                        });
+                    }
+                ));
             };
             viewModel.cloneGraph = function() {
                 newGraph(arches.urls.clone_graph(viewModel.graph.graphid()));
@@ -110,17 +192,20 @@ define([
                     contentType: false,
                     success: function(response) {
                         if (response[0].length != 0) {
+                            // eslint-disable-next-line no-constant-condition
                             if (typeof(response[0])) {
                                 response = response[0].join('<br />');
                             }
-                            viewModel.alert(new AlertViewModel('ep-alert-red', arches.graphImportFailed.title, response));
+                            viewModel.alert(new AlertViewModel('ep-alert-red', arches.translations.graphImportFailed.title, response));
                         } else {
                             viewModel.loading(false);
                             window.open(arches.urls.graph_designer(response[1].graph_id), '_blank');
                         }
                     },
                     error: function(response) {
-                        viewModel.alert(new AlertViewModel('ep-alert-red', arches.graphImportFailed.title, 'Please contact your system administrator for more details.'));
+                        viewModel.alert(
+                            new AlertViewModel('ep-alert-red', arches.translations.graphImportFailed.title, arches.translations.pleaseContactSystemAdministrator)
+                        );
                         viewModel.loading(false);
                     },
                 });
@@ -129,23 +214,28 @@ define([
                 $("#fileupload").trigger('click');
             };
             viewModel.deleteInstances = function() {
-                viewModel.alert(new AlertViewModel('ep-alert-red', arches.confirmAllResourceDelete.title, arches.confirmAllResourceDelete.text, function() {
-                    return;
-                }, function(){
-                    viewModel.loading(true);
-                    $.ajax({
-                        type: "DELETE",
-                        url: arches.urls.delete_instances(viewModel.graph.graphid()),
-                        complete: function(response, status) {
-                            viewModel.loading(false);
-                            if (status === 'success') {
-                                viewModel.alert(new AlertViewModel('ep-alert-blue', response.responseJSON.title, response.responseJSON.message));
-                            } else {
-                                viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
+                viewModel.alert(new AlertViewModel(
+                    'ep-alert-red', 
+                    arches.translations.confirmAllResourceDelete.title, 
+                    arches.translations.confirmAllResourceDelete.text, 
+                    function() {
+                        return;
+                    }, function(){
+                        viewModel.loading(true);
+                        $.ajax({
+                            type: "DELETE",
+                            url: arches.urls.delete_instances(viewModel.graph.graphid()),
+                            complete: function(response, status) {
+                                viewModel.loading(false);
+                                if (status === 'success') {
+                                    viewModel.alert(new AlertViewModel('ep-alert-blue', response.responseJSON.title, response.responseJSON.message));
+                                } else {
+                                    viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
+                                }
                             }
-                        }
-                    });
-                }));
+                        });
+                    }
+                ));
             };
             viewModel.graph.ontology = ko.computed(function() {
                 return viewModel.ontologies().find(function(obj) {
@@ -175,8 +265,9 @@ define([
 
             viewModel.graphModel.on('changed', function(model, response) {
                 viewModel.alert(null);
-                viewModel.loading(false);
+                // viewModel.loading(false);  // TODO: @cbyrd 8842 disable page refresh on branch append
                 if (response.status !== 200) {
+                    viewModel.loading(false);
                     viewModel.alert(new JsonErrorAlertViewModel('ep-alert-red', response.responseJSON));
                 }
             });
@@ -356,7 +447,7 @@ define([
             var correspondingCard = function(item, cardTree){
                 var cardList = cardTree.cachedFlatTree;
                 if (cardList === undefined) {
-                    var cardList = cardTree.flattenTree(cardTree.topCards(), []);
+                    cardList = cardTree.flattenTree(cardTree.topCards(), []);
                     cardTree.cachedFlatTree = cardList;
                 }
                 var res;
