@@ -4,8 +4,9 @@ define([
     'backbone',
     'knockout',
     'arches',
+    'views/components/simple-switch',
     'bindings/chosen'
-], function($, _, Backbone, ko, arches) {
+], function($, _, Backbone, ko) {
     var NodeFormView = Backbone.View.extend({
         /**
         * A backbone view representing a node form
@@ -78,6 +79,11 @@ define([
                 return isImmutable;
             };
 
+            this.extendNode = function(node, parameters)
+            {
+                return _.extend(node, parameters);
+            };
+
             this.toggleRequired = function() {
                 var isImmutable = self.checkIfImmutable();
                 if (isImmutable === false) {
