@@ -2,18 +2,21 @@ define([
     'jquery',
     'knockout',
     'underscore',
+    'arches',
     'turf',
     'geohash',
     'views/base-manager',
     'models/node',
     'viewmodels/alert',
     'views/components/widgets/map/bin-feature-collection',
-    'map-layer-manager-data',
-    'arches',
+    'views/map-layer-manager-data',
     'bindings/mapbox-gl',
     'bindings/codemirror',
-    'datatype-config-components'
-], function($, ko, _, turf, geohash, BaseManagerView, NodeModel, AlertViewModel, binFeatureCollection, data, arches) {
+    'codemirror/mode/javascript/javascript',
+    'datatype-config-components',
+    'views/components/icon-selector',
+    'views/components/datatypes/geojson-feature-collection',
+], function($, ko, _, arches, turf, geohash, BaseManagerView, NodeModel, AlertViewModel, binFeatureCollection, data) {
     var vm = {
         map: null,
         geomNodes: [],
@@ -116,31 +119,36 @@ define([
             layer.searchonly(_layer.searchonly);
         };
         layer.delete = function() {
-            pageView.viewModel.alert(new AlertViewModel('ep-alert-red', arches.confirmMaplayerDelete.title, arches.confirmMaplayerDelete.text, function() {
-                return;
-            }, function(){
-                vm.loading(true);
-                $.ajax({
-                    type: "DELETE",
-                    url: window.location.pathname + '/' + layer.maplayerid,
-                    success: function(response) {
-                        mapLayers.remove(layer);
-                        arches.mapLayers = _.without(arches.mapLayers, _.findWhere(arches.mapLayers, {
-                            maplayerid: layer.maplayerid
-                        }));
-                        var selection = null;
-                        var layerList = ko.unwrap(vm.selectedList());
-                        if (layerList && layerList.length > 0) {
-                            selection = layerList[0];
+            pageView.viewModel.alert(new AlertViewModel(
+                'ep-alert-red', 
+                arches.translations.confirmMaplayerDelete.title, 
+                arches.translations.confirmMaplayerDelete.text, 
+                function() {
+                    return;
+                }, function(){
+                    vm.loading(true);
+                    $.ajax({
+                        type: "DELETE",
+                        url: window.location.pathname + '/' + layer.maplayerid,
+                        success: function(response) {
+                            mapLayers.remove(layer);
+                            arches.mapLayers = _.without(arches.mapLayers, _.findWhere(arches.mapLayers, {
+                                maplayerid: layer.maplayerid
+                            }));
+                            var selection = null;
+                            var layerList = ko.unwrap(vm.selectedList());
+                            if (layerList && layerList.length > 0) {
+                                selection = layerList[0];
+                            }
+                            vm.selection(selection);
+                            pageView.viewModel.loading(false);
+                        },
+                        error: function(response) {
+                            pageView.viewModel.loading(false);
                         }
-                        vm.selection(selection);
-                        pageView.viewModel.loading(false);
-                    },
-                    error: function(response) {
-                        pageView.viewModel.loading(false);
-                    }
-                });
-            }));
+                    });
+                }
+            ));
         };
     });
 
@@ -226,7 +234,6 @@ define([
                 source: node,
                 datatypelookup: datatypelookup,
                 icons: data.icons,
-                graph: undefined,
                 layer: _.find(data.resource_map_layers, function(layer) {
                     return layer.nodeid === node.nodeid;
                 }),
@@ -372,7 +379,7 @@ define([
 
         searchAggregations.subscribe(updateSearchResultsLayer);
         if (ko.isObservable(bins)) {
-        	bins.subscribe(updateSearchResultsLayer);
+            bins.subscribe(updateSearchResultsLayer);
         }
         updateSearchResultsLayer();
     };
