@@ -2,6 +2,8 @@ define([
     'jquery',
     'underscore',
     'knockout',
+    'arches',
+    'report-templates',
     'views/base-manager',
     'viewmodels/alert',
     'viewmodels/alert-json',
@@ -9,15 +11,11 @@ define([
     'models/report',
     'viewmodels/card',
     'viewmodels/provisional-tile',
-    'arches',
-    'resource-editor-data',
-    'report-templates',
+    'views/resource/resource-editor-data',
     'bindings/resizable-sidepanel',
     'bindings/sortable',
-    'widgets',
-    'card-components',
     'moment',
-], function($, _, ko, BaseManagerView, AlertViewModel, JsonErrorAlertViewModel, GraphModel, ReportModel, CardViewModel, ProvisionalTileViewModel, arches, data, reportLookup) {
+], function($, _, ko, arches, reportLookup, BaseManagerView, AlertViewModel, JsonErrorAlertViewModel, GraphModel, ReportModel, CardViewModel, ProvisionalTileViewModel, data) {
     var handlers = {
         'after-update': [],
         'tile-reset': []
@@ -27,7 +25,23 @@ define([
     var loading = ko.observable(false);
     var selection = ko.observable('root');
     var scrollTo = ko.observable();
-    var displayname = ko.observable(data.displayname);
+    let parsedDisplayName = undefined;
+    try { 
+        if(typeof data.displayname == 'string') {
+            parsedDisplayName = JSON.parse(data.displayname);
+        }
+    } catch(e){
+        // empty
+    }
+
+    let displayNameValue = undefined;
+    if(parsedDisplayName){
+        const defaultLanguageValue = parsedDisplayName?.[arches.activeLanguage]?.value;
+        displayNameValue = defaultLanguageValue ? defaultLanguageValue : "(" + parsedDisplayName[Object.keys(parsedDisplayName).filter(languageKey => languageKey != arches.activeLanguage)?.[0]]?.value + ")";
+    } else {
+        displayNameValue = data.displayname;
+    }
+    const displayname = ko.observable(displayNameValue);
     var resourceId = ko.observable(data.resourceid);
     var appliedFunctions = ko.observable(data['appliedFunctions']);
     var primaryDescriptorFunction = ko.observable(data['primaryDescriptorFunction']);
@@ -83,7 +97,15 @@ define([
         var nodegroup = _.find(data.nodegroups, function(group) {
             return group.nodegroupid === card.nodegroup_id;
         });
-        return !nodegroup || !nodegroup.parentnodegroup_id;
+        return nodegroup && !nodegroup.parentnodegroup_id;
+    }).sort((firstEl, secondEl) => {
+        if(firstEl.sortorder < secondEl.sortorder) {
+            return -1;
+        }
+        if(firstEl.sortorder === secondEl.sortorder) {
+            return 0;
+        }
+        return 1;
     }).map(function(card) {
         return new CardViewModel({
             card: card,
@@ -142,6 +164,7 @@ define([
         graphiconclass: data.graphiconclass,
         relationship_types: data.relationship_types,
         userIsCreator: userIsCreator,
+        showGrid: ko.observable(false),
         creator: creator,
         // appliedFunctions: appliedFunctions(),
         graph: {
@@ -157,6 +180,10 @@ define([
         collapseAll: function() {
             toggleAll(false);
         },
+        toggleGrid: () => {
+            vm.showGrid(!vm.showGrid());
+        },
+        activeLanguageDir: ko.observable(arches.activeLanguageDir),
         rootExpanded: ko.observable(true),
         topCards: topCards,
         selection: selection,
@@ -186,45 +213,74 @@ define([
         resourceId: resourceId,
         reportLookup: reportLookup,
         copyResource: function() {
-            if (resourceId()) {
+            if (data.graph && !data.graph.publication_id) {
+                vm.alert(new AlertViewModel(
+                    'ep-alert-red', 
+                    arches.translations.resourceHasUnpublishedGraph.title, 
+                    arches.translations.resourceHasUnpublishedGraph.text, 
+                    null, 
+                    function(){}
+                ));
+            }
+            else if (resourceId()) {
                 vm.menuActive(false);
                 loading(true);
                 $.ajax({
                     type: "GET",
                     url: arches.urls.resource_copy.replace('//', '/' + resourceId() + '/'),
                     success: function(data) {
-                        vm.alert(new AlertViewModel('ep-alert-blue', arches.resourceCopySuccess.title, "<a style='color: #fff; font-weight: 700;' target='_blank' href=" + arches.urls.resource_editor + data.resourceid + ">" + arches.resourceCopySuccess.text + "</a>", null, function(){}));
+                        vm.alert(new AlertViewModel(
+                            'ep-alert-blue', 
+                            arches.translations.resourceCopySuccess.title, 
+                            "<a style='color: #fff; font-weight: 700;' target='_blank' href=" + arches.urls.resource_editor + data.resourceid + ">" + arches.translations.resourceCopySuccess.text + "</a>", 
+                            null, 
+                            function(){}
+                        ));
                     },
                     error: function() {
-                        vm.alert(new AlertViewModel('ep-alert-red', arches.resourceCopyFailed.title, arches.resourceCopyFailed.text, null, function(){}));
+                        vm.alert(new AlertViewModel('ep-alert-red', arches.translations.resourceCopyFailed.title, arches.translations.resourceCopyFailed.text, null, function(){}));
                     },
                     complete: function() {
                         loading(false);
                     },
                 });
             }
+            else {
+                vm.alert(new AlertViewModel(
+                    'ep-alert-red', 
+                    arches.translations.resourceCopyFailed.title, 
+                    arches.translations.resourceCopyFailed.text, 
+                    null, 
+                    function(){}
+                ));
+            }
         },
         deleteResource: function() {
             if (resourceId()) {
                 vm.menuActive(false);
-                vm.alert(new AlertViewModel('ep-alert-red', arches.confirmResourceDelete.title, arches.confirmResourceDelete.text, function() {
-                    return;
-                }, function(){
-                    loading(true);
-                    $.ajax({
-                        type: "DELETE",
-                        url: arches.urls.resource_editor + resourceId(),
-                        error: function(err) {
-                            vm.alert(new JsonErrorAlertViewModel('ep-alert-red', err.responseJSON));
-                        },
-                        complete: function(request, status) {
-                            loading(false);
-                            if (status === 'success') {
-                                vm.navigate(arches.urls.resource);
-                            }
-                        },
-                    });
-                }));
+                vm.alert(new AlertViewModel('ep-alert-red', 
+                    arches.translations.confirmResourceDelete.title, 
+                    arches.translations.confirmResourceDelete.text, 
+                    function() {
+                        return;
+                    }, 
+                    function(){
+                        loading(true);
+                        $.ajax({
+                            type: "DELETE",
+                            url: arches.urls.resource_editor + resourceId(),
+                            error: function(err) {
+                                vm.alert(new JsonErrorAlertViewModel('ep-alert-red', err.responseJSON));
+                            },
+                            complete: function(request, status) {
+                                loading(false);
+                                if (status === 'success') {
+                                    vm.navigate(arches.urls.resource);
+                                }
+                            },
+                        });
+                    }
+                ));
             }
         },
         viewEditHistory: function() {
