@@ -25,18 +25,21 @@ from uuid import UUID
 from django.db import transaction
 from django.db.models import Q
 from django.contrib.auth.models import User, Group, Permission
+from django.forms.models import model_to_dict
 from django.core.exceptions import ObjectDoesNotExist
 from django.utils.translation import ugettext as _
+from django.utils.translation import get_language
 from arches.app.models import models
 from arches.app.models.models import EditLog
 from arches.app.models.models import TileModel
 from arches.app.models.concept import get_preflabel_from_valueid
 from arches.app.models.system_settings import settings
 from arches.app.search.search_engine_factory import SearchEngineInstance as se
-from arches.app.search.mappings import TERMS_INDEX, RESOURCE_RELATIONS_INDEX, RESOURCES_INDEX
+from arches.app.search.mappings import TERMS_INDEX, RESOURCES_INDEX
 from arches.app.search.elasticsearch_dsl_builder import Query, Bool, Terms, Nested
 from arches.app.tasks import index_resource
 from arches.app.utils import import_class_from_string, task_management
+from arches.app.utils.i18n import get_localized_value
 from arches.app.utils.label_based_graph import LabelBasedGraph
 from arches.app.utils.label_based_graph_v2 import LabelBasedGraph as LabelBasedGraphV2
 from guardian.shortcuts import assign_perm, remove_perm
@@ -74,13 +77,32 @@ class Resource(models.ResourceInstance):
         graph_function = models.FunctionXGraph.objects.filter(
             graph_id=self.graph_id, function__functiontype="primarydescriptors"
         ).select_related("function")
+
+        if self.descriptors is None:
+            self.descriptors = {}
+
+        if self.name is None:
+            self.name = {}
+
+        requested_language = None
+        if context is not None and "language" in context:
+            requested_language = context["language"]
+        language = requested_language or get_language()
+
+        if language not in self.descriptors:
+            self.descriptors[language] = {}
+
         if len(graph_function) == 1:
             module = graph_function[0].function.get_class_module()()
-            return module.get_primary_descriptor_from_nodes(
+            self.descriptors[language][descriptor] = module.get_primary_descriptor_from_nodes(
                 self, graph_function[0].config["descriptor_types"][descriptor], context
             )
+            if descriptor == "name" and self.descriptors[language][descriptor] is not None:
+                self.name[language] = self.descriptors[language][descriptor]
         else:
-            return "undefined"
+            self.descriptors[language][descriptor] = None
+
+        return self.descriptors[language][descriptor]
 
     def displaydescription(self, context=None):
         return self.get_descriptor("description", context)
@@ -117,10 +139,7 @@ class Resource(models.ResourceInstance):
         index -- True(default) to index the resource, otherwise don't index the resource
 
         """
-        graph = models.GraphModel.objects.get(graphid=self.graph_id)
-        if graph.isactive is False:
-            message = _("This model is not yet active; unable to save.")
-            raise ModelInactiveError(message)
+        # TODO: 7783 cbyrd throw error if graph is unpublished
         request = kwargs.pop("request", None)
         user = kwargs.pop("user", None)
         index = kwargs.pop("index", True)
@@ -258,6 +277,8 @@ class Resource(models.ResourceInstance):
                     doc, doc_id = es_index.get_documents_to_index(self, document["tiles"])
                     es_index.index_document(document=doc, id=doc_id)
 
+            super(Resource, self).save()
+
     def get_documents_to_index(self, fetchTiles=True, datatype_factory=None, node_datatypes=None, context=None):
         """
         Gets all the documents nessesary to index a single resource
@@ -279,9 +300,43 @@ class Resource(models.ResourceInstance):
         document["displayname"] = None
         document["root_ontology_class"] = self.get_root_ontology()
         document["legacyid"] = self.legacyid
-        document["displayname"] = self.displayname(context)
-        document["displaydescription"] = self.displaydescription(context)
-        document["map_popup"] = self.map_popup(context)
+
+        document["displayname"] = []
+        document["displaydescription"] = []
+        document["map_popup"] = []
+        for lang in settings.LANGUAGES:
+            if context is None:
+                context = {}
+            context["language"] = lang[0]
+            displayname = self.displayname(context)
+            if displayname is not None and displayname != "Undefined":
+                try:
+                    display_name = JSONDeserializer().deserialize(displayname)
+                    for key in display_name.keys():
+                        document["displayname"].append({"value": display_name[key]["value"], "language": key})
+                except:
+                    display_name = {"value": displayname, "language": lang[0]}
+                    document["displayname"].append(display_name)
+
+            displaydescription = self.displaydescription(context)
+            if displaydescription is not None and displaydescription != "Undefined":
+                try:
+                    display_description = JSONDeserializer().deserialize(displaydescription)
+                    for key in display_description.keys():
+                        document["displaydescription"].append({"value": display_description[key]["value"], "language": key})
+                except:
+                    display_description = {"value": displaydescription, "language": lang[0]}
+                    document["displaydescription"].append(display_description)
+
+            mappopup = self.map_popup(context)
+            if mappopup is not None and mappopup != "Undefined":
+                try:
+                    map_popup = JSONDeserializer().deserialize(mappopup)
+                    for key in map_popup.keys():
+                        document["map_popup"].append({"value": map_popup[key]["value"], "language": key})
+                except:
+                    map_popup = {"value": mappopup, "language": lang[0]}
+                    document["map_popup"].append(map_popup)
 
         tiles = list(models.TileModel.objects.filter(resourceinstance=self)) if fetchTiles else self.tiles
 
@@ -310,15 +365,17 @@ class Resource(models.ResourceInstance):
                     datatype_instance = datatype_factory.get_instance(datatype)
                     datatype_instance.append_to_document(document, nodevalue, nodeid, tile)
                     node_terms = datatype_instance.get_search_terms(nodevalue, nodeid)
+
                     for index, term in enumerate(node_terms):
                         terms.append(
                             {
-                                "_id": str(nodeid) + str(tile.tileid) + str(index),
+                                "_id": str(nodeid) + str(tile.tileid) + str(index) + term.lang,
                                 "_source": {
-                                    "value": term,
+                                    "value": term.value,
                                     "nodeid": nodeid,
                                     "nodegroupid": tile.nodegroup_id,
                                     "tileid": tile.tileid,
+                                    "language": term.lang,
                                     "resourceinstanceid": tile.resourceinstance_id,
                                     "provisional": False,
                                 },
@@ -338,21 +395,22 @@ class Resource(models.ResourceInstance):
                                     datatype_instance = datatype_factory.get_instance(datatype)
                                     datatype_instance.append_to_document(document, nodevalue, nodeid, tile, True)
                                     node_terms = datatype_instance.get_search_terms(nodevalue, nodeid)
+
                                     for index, term in enumerate(node_terms):
                                         terms.append(
                                             {
-                                                "_id": str(nodeid) + str(tile.tileid) + str(index),
+                                                "_id": str(nodeid) + str(tile.tileid) + str(index) + term.lang,
                                                 "_source": {
-                                                    "value": term,
+                                                    "value": term.value,
                                                     "nodeid": nodeid,
                                                     "nodegroupid": tile.nodegroup_id,
                                                     "tileid": tile.tileid,
+                                                    "language": term.lang,
                                                     "resourceinstanceid": tile.resourceinstance_id,
                                                     "provisional": True,
                                                 },
                                             }
                                         )
-
         return document, terms
 
     def delete(self, user={}, index=True, transaction_id=None):
@@ -366,10 +424,7 @@ class Resource(models.ResourceInstance):
         # - that the index for the to-be-deleted resource gets deleted
 
         permit_deletion = False
-        graph = models.GraphModel.objects.get(graphid=self.graph_id)
-        if graph.isactive is False:
-            message = _("This model is not yet active; unable to delete.")
-            raise ModelInactiveError(message)
+        # TODO: 7783 cbyrd throw error if graph is unpublished
         if user != {}:
             user_is_reviewer = user_is_resource_reviewer(user)
             if user_is_reviewer is False:
@@ -386,7 +441,7 @@ class Resource(models.ResourceInstance):
             for related_resource in models.ResourceXResource.objects.filter(
                 Q(resourceinstanceidfrom=self.resourceinstanceid) | Q(resourceinstanceidto=self.resourceinstanceid)
             ):
-                related_resource.delete(deletedResourceId=self.resourceinstanceid, index=False)
+                related_resource.delete(deletedResourceId=self.resourceinstanceid)
 
             if index:
                 self.delete_index()
@@ -418,14 +473,6 @@ class Resource(models.ResourceInstance):
         query.add_query(bool_query)
         query.delete(index=TERMS_INDEX)
 
-        # delete any related resource index entries
-        query = Query(se)
-        bool_query = Bool()
-        bool_query.should(Terms(field="resourceinstanceidto", terms=[resourceinstanceid]))
-        bool_query.should(Terms(field="resourceinstanceidfrom", terms=[resourceinstanceid]))
-        query.add_query(bool_query)
-        query.delete(index=RESOURCE_RELATIONS_INDEX)
-
         # reindex any related resources
         query = Query(se)
         bool_query = Bool()
@@ -484,12 +531,24 @@ class Resource(models.ResourceInstance):
         Returns an object that lists the related resources, the relationship types, and a reference to the current resource
 
         """
+
+        # TODO This function is very similar to code in search results and the resource view. Needs to be centralized.
+        def get_localized_descriptor(document, descriptor_type):
+            language_codes = (get_language(), settings.LANGUAGE_CODE)
+            descriptor = document["_source"][descriptor_type]
+            result = descriptor[0] if len(descriptor) > 0 else {"value": _("Undefined")}
+            for language_code in language_codes:
+                for entry in descriptor:
+                    if entry["language"] == language_code and entry["value"] != "":
+                        return entry["value"]
+            return result["value"]
+
         if not graphs:
             graphs = list(
                 models.GraphModel.objects.all()
                 .exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
                 .exclude(isresource=False)
-                .exclude(isactive=False)
+                .exclude(publication=None)
             )
 
         graph_lookup = {
@@ -499,55 +558,54 @@ class Resource(models.ResourceInstance):
         ret = {"resource_instance": self, "resource_relationships": [], "related_resources": [], "node_config_lookup": graph_lookup}
 
         if page > 0:
-            limit = settings.RELATED_RESOURCES_PER_PAGE
-            start = limit * int(page - 1)
+            number_per_page = settings.RELATED_RESOURCES_PER_PAGE
+            start = number_per_page * int(page - 1)
+            limit = number_per_page * page
 
         def get_relations(resourceinstanceid, start, limit, resourceinstance_graphid=None):
-            query = Query(se, start=start, limit=limit)
-            bool_filter = Bool()
-            bool_filter.should(Terms(field="resourceinstanceidfrom", terms=resourceinstanceid))
-            bool_filter.should(Terms(field="resourceinstanceidto", terms=resourceinstanceid))
+            final_query = Q(resourceinstanceidfrom_id=resourceinstanceid) | Q(resourceinstanceidto_id=resourceinstanceid)
 
             if resourceinstance_graphid:
-                graph_filter = Bool()
-                to_graph_id_filter = Bool()
-                to_graph_id_filter.filter(Terms(field="resourceinstancefrom_graphid", terms=str(self.graph_id)))
-                to_graph_id_filter.filter(Terms(field="resourceinstanceto_graphid", terms=resourceinstance_graphid))
-                graph_filter.should(to_graph_id_filter)
+                to_graph_id_filter = Q(resourceinstancefrom_graphid_id=str(self.graph_id)) & Q(
+                    resourceinstanceto_graphid_id=resourceinstance_graphid
+                )
+                from_graph_id_filter = Q(resourceinstancefrom_graphid_id=resourceinstance_graphid) & Q(
+                    resourceinstanceto_graphid_id=str(self.graph_id)
+                )
+                final_query = final_query & (to_graph_id_filter | from_graph_id_filter)
 
-                from_graph_id_filter = Bool()
-                from_graph_id_filter.filter(Terms(field="resourceinstancefrom_graphid", terms=resourceinstance_graphid))
-                from_graph_id_filter.filter(Terms(field="resourceinstanceto_graphid", terms=str(self.graph_id)))
-                graph_filter.should(from_graph_id_filter)
-                bool_filter.must(graph_filter)
+            relations = {
+                "total": models.ResourceXResource.objects.filter(final_query).count(),
+                "relations": models.ResourceXResource.objects.filter(final_query)[start:limit],
+            }
 
-            query.add_query(bool_filter)
-
-            return query.search(index=RESOURCE_RELATIONS_INDEX)
+            return relations  # resourceinstance_graphid = "00000000-886a-374a-94a5-984f10715e3a"
 
         resource_relations = get_relations(
-            resourceinstanceid=self.resourceinstanceid, start=start, limit=limit, resourceinstance_graphid=resourceinstance_graphid,
+            resourceinstanceid=self.resourceinstanceid,
+            start=start,
+            limit=limit,
+            resourceinstance_graphid=resourceinstance_graphid,
         )
 
-
-
-        ret["total"] = resource_relations["hits"]["total"]
+        ret["total"] = {"value": resource_relations["total"]}
         instanceids = set()
 
         restricted_instances = get_restricted_instances(user, se) if user is not None else []
-        for relation in resource_relations["hits"]["hits"]:
+        for relation in resource_relations["relations"]:
+            relation = model_to_dict(relation)
             try:
-                preflabel = get_preflabel_from_valueid(relation["_source"]["relationshiptype"], lang)
-                relation["_source"]["relationshiptype_label"] = preflabel["value"] or ""
+                preflabel = get_preflabel_from_valueid(relation["relationshiptype"], lang)
+                relation["relationshiptype_label"] = preflabel["value"] or ""
             except:
-                relation["_source"]["relationshiptype_label"] = relation["_source"]["relationshiptype"] or ""
+                relation["relationshiptype_label"] = relation["relationshiptype"] or ""
 
-            resourceid_to = relation["_source"]["resourceinstanceidto"]
-            resourceid_from = relation["_source"]["resourceinstanceidfrom"]
+            resourceid_to = relation["resourceinstanceidto"]
+            resourceid_from = relation["resourceinstanceidfrom"]
             if resourceid_to not in restricted_instances and resourceid_from not in restricted_instances:
-                ret["resource_relationships"].append(relation["_source"])
-                instanceids.add(resourceid_to)
-                instanceids.add(resourceid_from)
+                ret["resource_relationships"].append(relation)
+                instanceids.add(str(resourceid_to))
+                instanceids.add(str(resourceid_from))
             else:
                 ret["total"]["value"] -= 1
 
@@ -557,6 +615,8 @@ class Resource(models.ResourceInstance):
         if len(instanceids) > 0:
             related_resources = se.search(index=RESOURCES_INDEX, id=list(instanceids))
             if related_resources:
+
+
                 for resource in related_resources["docs"]:
                     relations = get_relations(
                         resourceinstanceid=resource["_id"],
@@ -564,7 +624,15 @@ class Resource(models.ResourceInstance):
                         limit=0,
                     )
                     if resource["found"]:
-                        resource["_source"]["total_relations"] = relations["hits"]["total"]
+                        resource["_source"]["total_relations"] = relations["total"]
+
+                        for descriptor_type in ("displaydescription", "displayname"):
+                            descriptor = get_localized_descriptor(resource, descriptor_type)
+                            if descriptor:
+                                resource["_source"][descriptor_type] = descriptor
+                            else:
+                                resource["_source"][descriptor_type] = _("Undefined")
+
                         ret["related_resources"].append(resource["_source"])
 
         return ret
@@ -604,7 +672,7 @@ class Resource(models.ResourceInstance):
 
         return new_resource
 
-    def serialize(self, fields=None, exclude=None):
+    def serialize(self, fields=None, exclude=None, **kwargs):
         """
         Serialize to a different form then used by the internal class structure
 
@@ -714,9 +782,19 @@ def is_uuid(value_to_test):
         return False
 
 
-class ModelInactiveError(Exception):
+class PublishedModelError(Exception):
     def __init__(self, message, code=None):
-        self.title = _("Model Inactive Error")
+        self.title = _("Published Model Error")
+        self.message = message
+        self.code = code
+
+    def __str__(self):
+        return repr(self.message)
+
+
+class UnpublishedModelError(Exception):
+    def __init__(self, message, code=None):
+        self.title = _("Unpublished Model Error")
         self.message = message
         self.code = code
 
