@@ -59,13 +59,19 @@ class AdvancedSearch(BaseSearchFilter):
         resource_graphs = (
             models.GraphModel.objects.exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
             .exclude(isresource=False)
-            .exclude(isactive=False)
+            .exclude(publication=None)
         )
         searchable_datatypes = [d.pk for d in models.DDataType.objects.filter(issearchable=True)]
         searchable_nodes = models.Node.objects.filter(
-            graph__isresource=True, graph__isactive=True, datatype__in=searchable_datatypes, issearchable=True
+            graph__isresource=True,
+            graph__publication__isnull=False,
+            datatype__in=searchable_datatypes,
+            issearchable=True,
+        )
+
+        resource_cards = models.CardModel.objects.filter(graph__isresource=True, graph__publication__isnull=False).select_related(
+            "nodegroup"
         )
-        resource_cards = models.CardModel.objects.filter(graph__isresource=True, graph__isactive=True).prefetch_related("nodegroup")
         cardwidgets = models.CardXNodeXWidget.objects.filter(node__in=searchable_nodes)
         datatypes = models.DDataType.objects.all()
 
