@@ -18,10 +18,11 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import json
 from arches import __version__
-from arches.app.models.models import GroupMapSettings
+from arches.app.models.models import GroupMapSettings, Language
 from arches.app.models.system_settings import settings
 from arches.app.utils.geo_utils import GeoUtils
-from arches.app.utils.betterJSONSerializer import JSONSerializer, JSONDeserializer
+from arches.app.utils.betterJSONSerializer import JSONSerializer
+from django.utils.translation import get_language, get_language_bidi
 
 
 def livereload(request):
@@ -64,7 +65,8 @@ def map_info(request):
     }
 
 
-def app_settings(request):
+def app_settings(request=None):
+    languages = Language.objects.all()
     return {
         "app_settings": {
             "VERSION": __version__,
@@ -76,6 +78,10 @@ def app_settings(request):
             "RENDERERS": settings.RENDERERS,
             "ACCESSIBILITY_MODE": settings.ACCESSIBILITY_MODE,
             "FORCE_SCRIPT_NAME": settings.FORCE_SCRIPT_NAME if settings.FORCE_SCRIPT_NAME is not None else "",
+            "ACTIVE_LANGUAGE": get_language(),
+            "ACTIVE_LANGUAGE_DIR": "rtl" if get_language_bidi() else "ltr",
+            "LANGUAGES": JSONSerializer().serialize(languages) if len(languages) != 0 else JSONSerializer().serialize([]),
             "RESTRICT_CELERY_EXPORT_FOR_ANONYMOUS_USER": settings.RESTRICT_CELERY_EXPORT_FOR_ANONYMOUS_USER,
+            "DEBUG": settings.DEBUG,
         }
     }
