@@ -11,7 +11,7 @@ from io import BytesIO
 from arches.app.models.graph import Graph
 from arches.app.models.concept import Concept
 from arches.app.models.system_settings import settings
-from arches.app.models.models import CardXNodeXWidget, Node, Resource2ResourceConstraint, FunctionXGraph, Value
+from arches.app.models.models import CardXNodeXWidget, Node, Resource2ResourceConstraint, FunctionXGraph, Value, GraphXPublishedGraph
 from arches.app.utils.betterJSONSerializer import JSONSerializer, JSONDeserializer
 from collections import OrderedDict
 from operator import itemgetter
@@ -124,26 +124,26 @@ def get_graphs_for_export(graphids=None):
     graphs = {}
     graphs["graph"] = []
     if graphids is None or graphids[0] == "all" or graphids == [""]:
-        resource_graph_query = JSONSerializer().serializeToPython(
-            Graph.objects.all().exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID), exclude=["widgets"]
-        )
+        resource_graphs = Graph.objects.all().exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
     elif graphids[0] == "resource_models":
-        resource_graph_query = JSONSerializer().serializeToPython(
-            Graph.objects.filter(isresource=True).exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID), exclude=["widgets"]
-        )
+        resource_graphs = Graph.objects.filter(isresource=True).exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
     elif graphids[0] == "branches":
-        resource_graph_query = JSONSerializer().serializeToPython(
-            Graph.objects.filter(isresource=False).exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID), exclude=["widgets"]
-        )
+        resource_graphs = Graph.objects.filter(isresource=False).exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
     else:
         try:
-            resource_graph_query = JSONSerializer().serializeToPython(Graph.objects.filter(graphid__in=graphids), exclude=["widgets"])
+            resource_graphs = Graph.objects.filter(graphid__in=graphids)
         except:
             # this warning should never get thrown while doing an export from the UI, but maybe it should be moved somewhere else.
             print("*" * 80)
             print('"{0}" contains/is not a valid graphid or option for this command.'.format(",".join(graphids)))
             print("*" * 80)
             sys.exit()
+    for resource_graph in resource_graphs:
+        resource_graph.refresh_from_database()
+
+    resource_graph_query = JSONSerializer().serializeToPython(
+        resource_graphs, exclude=["widgets"], force_recalculation=True, use_raw_i18n_json=True
+    )
 
     for resource_graph in resource_graph_query:
         function_ids = []
@@ -155,9 +155,19 @@ def get_graphs_for_export(graphids=None):
         del resource_graph["functions"]
         del resource_graph["domain_connections"]
         resource_graph["cards_x_nodes_x_widgets"] = JSONSerializer().serializeToPython(
-            get_card_x_node_x_widget_data_for_export(resource_graph)
+            get_card_x_node_x_widget_data_for_export(resource_graph), use_raw_i18n_json=True
         )
         resource_graph["resource_2_resource_constraints"] = JSONSerializer().serializeToPython(r2r_constraints_for_export(resource_graph))
+
+        publication_id = resource_graph.get("publication_id")
+        publication = None
+
+        if publication_id:
+            publication = JSONDeserializer().deserialize(JSONSerializer().serialize(GraphXPublishedGraph.objects.get(pk=publication_id)))
+
+        resource_graph["publication"] = publication
+        del resource_graph["publication_id"]
+
         graphs["graph"].append(resource_graph)
     return sort(graphs)
 
@@ -226,7 +236,7 @@ def create_mapping_configuration_file(graphid, include_concepts=True, data_dir=N
                             for concept in node.config["options"]:
                                 concepts[concept["id"]] = concept["text"]
 
-                        values[node.name] = OrderedDict(sorted(list(concepts.items()), key=itemgetter(1)))
+                        values[node.name] = OrderedDict(concepts.items())
 
         if include_concepts == True:
             try:
