@@ -284,6 +284,7 @@ class JsonLdReader(Reader):
         self.graphtree = None
         self.print_buf = []
         self.verbosity = kwargs.get("verbosity", 1)
+        self.ignore_errors = kwargs.get("ignore_errors", False)
         self.logger = logging.getLogger(__name__)
         for graph in models.GraphModel.objects.filter(isresource=True):
             node = models.Node.objects.get(graph_id=graph.pk, istopnode=True)
@@ -423,11 +424,19 @@ class JsonLdReader(Reader):
             self.root_json_document = jsonld_document
             try:
                 self.data_walk(jsonld_document, self.graphtree, result)
-            except:
+            except Exception as e:
+                err_msg_fail = f"FAILED to completely load resource with id: {self.resource.pk}\n"
+                self.logger.debug(err_msg_fail)
+                print(err_msg_fail)
                 if self.verbosity > 1:
                     for line in self.print_buf:
                         # print(line) # uncomment this line to print errors directly to the screen
                         self.logger.debug(line)
+                    err_msg_fail_detail = f"DETAILED ERROR MESSAGE\n{str(e)}"
+                    self.logger.debug(err_msg_fail_detail)
+                    print(err_msg_fail_detail)
+                if not self.ignore_errors:
+                    raise
 
 
     def is_semantic_node(self, graph_node):
@@ -471,12 +480,15 @@ class JsonLdReader(Reader):
         if indent and indent > 0:
             prefix = prefix + "   " * int(indent)
         self.print_buf.append(prefix + text)
+        if self.verbosity > 2:
+            print(prefix + text)
 
     def data_walk(self, data_node, tree_node, result, tile=None, indent=0):
         my_tiles = []
+        self.printline("Walk down non-literal branches in the data", indent, newline=True)
         self.printline(f"---" * 20, indent)
-        self.printline(tree_node["name"], indent)
-        self.printline(f"tile={tile}", indent)
+        # self.printline(tree_node["name"], indent)
+        # self.printline(f"tile={tile}", indent)
 
         # pre-seed as much of the cache as we can during the data-walk
         if "@id" in data_node and "@type" in data_node:
@@ -490,13 +502,25 @@ class JsonLdReader(Reader):
             # or "http://www.w3.org/2000/01/rdf-schema#label"
             if k in ["@id", "@type"]:
                 continue
+
+            # extract all @values for the current node
+            values = [
+                {
+                    "value": vi["@value"],
+                    "clss": vi.get("@type", "http://www.w3.org/2000/01/rdf-schema#Literal"),
+                    "language": vi.get("@language", None),
+                }
+                for vi in v
+                if "@value" in vi
+                and vi.get("@type", "http://www.w3.org/2000/01/rdf-schema#Literal") == "http://www.w3.org/2000/01/rdf-schema#Literal"
+            ]
+
             # always a list
             for vi in v:
                 if "@value" in vi:
-                    # We're a literal value
                     value = vi["@value"]
-                    clss = vi.get("@type", "http://www.w3.org/2000/01/rdf-schema#Literal")
                     uri = None
+                    clss = vi.get("@type", "http://www.w3.org/2000/01/rdf-schema#Literal")
                     is_literal = True
                 else:
                     # We're an entity
@@ -545,14 +569,14 @@ class JsonLdReader(Reader):
                 # if we made it this far then it means that we've found at least 1 match
                 options = tree_node["children"][key]
                 possible = []
-                ignore = []
 
                 # options is a list of potential matches in the graph tree
                 # based on property/class combination
 
+                self.printline(f"Trying to match data value:  '{value or uri}'", indent, newline=True)
+                self.printline(f"That has type:  '{k}'", indent)
                 for o in options:
-                    self.printline(f"Considering match to node: '{o['name']}'", indent + 1, newline=True)
-                    self.printline(f"Incoming value we're testing:  '{value or uri}'", indent + 1)
+                    self.printline(f"Considering match to graph node: '{o['name']}'", indent + 1, newline=True)
                     self.printline(f"New Nodegroup = {o['nodegroup_id'] == o['node_id']}", indent + 1)
                     self.printline(f"Parent tile id = {result['tile'].tileid if 'tile' in result else None}", indent + 1)
                     potential_tile = None
@@ -568,10 +592,17 @@ class JsonLdReader(Reader):
                             data={},
                         )
                     if is_literal and o["datatype"].is_a_literal_in_rdf():
-                        if len(o["datatype"].validate_from_rdf(value)) == 0:
-                            possible.append([o, value, potential_tile])
+                        # import each value separately if there are no languages in the values and this is card n string
+                        if o["datatype"].is_multilingual_rdf(values):
+                            if len(o["datatype"].validate_from_rdf(values)) == 0:
+                                possible.append([o, values, potential_tile])
+                            else:
+                                self.printline(f"Could not validate {values} as a {o['datatype']}", indent + 1)
                         else:
-                            self.printline(f"Could not validate {value} as a {o['datatype']}", indent + 1)
+                            if len(o["datatype"].validate_from_rdf(value)) == 0:
+                                possible.append([o, value, potential_tile])
+                            else:
+                                self.printline(f"Could not validate {value} as a {o['datatype']}", indent + 1)
                     elif not is_literal and not o["datatype"].is_a_literal_in_rdf():
                         if self.is_concept_node(uri):
                             self.printline("This is a concept node, so we'll test if the incoming data can fit here", indent + 1)
@@ -588,7 +619,11 @@ class JsonLdReader(Reader):
                             except:
                                 self.printline(f"Errored testing concept {uri} in collection {collid}", indent + 1)
                         elif self.is_semantic_node(o):
-                            possible.append([o, "", potential_tile])
+                            if uri != "":
+                                if o["node_id"] in uri:
+                                    possible.append([o, "", potential_tile])
+                            else:
+                                possible.append([o, "", potential_tile])
                         elif o["datatype"].accepts_rdf_uri(uri):
                             # self.printline(f"datatype for {o['name']} accepts uri", indent+1)
                             possible.append([o, uri, potential_tile])
@@ -596,10 +631,7 @@ class JsonLdReader(Reader):
                             # This is when the current option doesn't match, but could be
                             # non-ambiguous resource-instance vs semantic node
                             continue
-                    else:
-                        raise ValueError("No possible match?")
-
-                # self.printline(f"Possible is: {[x[0]['name'] for x in possible]}", indent+1)
+                # print(f"Possible is: {[x[0]['name'] for x in possible]}")
 
                 if not possible:
                     # self.printline(f"Tried: {options}")
@@ -613,6 +645,7 @@ class JsonLdReader(Reader):
                             # self.printline("Don't really create data, so pass anonymous result dict", indent + 1)
                             if p[2] is not None:
                                 tile = p[2]
+                            self.printline("Found multiple matches!", indent)
                             self.data_walk(vi, p[0], {}, tile, indent + 1)
                             possible2.append(p)
                         except Exception as e:
@@ -632,7 +665,10 @@ class JsonLdReader(Reader):
 
                 if not self.is_semantic_node(branch[0]):
                     graph_node = branch[0]
-                    node_value = graph_node["datatype"].from_rdf(vi)
+                    if graph_node["datatype"].is_multilingual_rdf(values):
+                        node_value = graph_node["datatype"].from_rdf(values)
+                    else:
+                        node_value = graph_node["datatype"].from_rdf(vi)
                     # node_value might be None if the validation of the datatype fails
                     # XXX Should we check this here, or raise in the datatype?
 
@@ -672,7 +708,7 @@ class JsonLdReader(Reader):
                 if branch[0]["datatype"].collects_multiple_values() and tile and str(tile.nodegroup.pk) == branch[0]["nodegroup_id"]:
                     # iterating through a root node *-list type
                     pass
-                elif bnodeid == branch[0]["nodegroup_id"]:
+                elif bnodeid == branch[0]["nodegroup_id"] and not (branch[0]["datatype"].is_multilingual_rdf(values) and bnodeid in result):
                     # Used to pick the previous tile in loop which MIGHT be the parent (but might not)
                     parenttile_id = result["tile"].tileid if "tile" in result else None
                     tile = Tile(
@@ -727,7 +763,6 @@ class JsonLdReader(Reader):
 
                 self.printline(f"Tile.data = {tile.data}", indent + 1)
                 if not is_literal:
-                    self.printline("Walk down non-literal branches in the data", indent + 1, newline=True)
                     self.data_walk(vi, branch[0], bnode, tile, indent + 1)
 
         if self.shouldSortTiles:
