@@ -1,3 +1,4 @@
+from typing import Iterable
 import uuid
 import django
 
@@ -14,7 +15,7 @@ from arches.app.models.system_settings import settings
 from arches.app.search.search_engine_factory import SearchEngineInstance as se
 from arches.app.search.elasticsearch_dsl_builder import Query, Term
 from arches.app.search.base_index import get_index
-from arches.app.search.mappings import TERMS_INDEX, CONCEPTS_INDEX, RESOURCE_RELATIONS_INDEX, RESOURCES_INDEX
+from arches.app.search.mappings import TERMS_INDEX, CONCEPTS_INDEX, RESOURCES_INDEX
 from arches.app.datatypes.datatypes import DataTypeFactory
 from arches.app.utils import import_class_from_string
 from datetime import datetime
@@ -50,7 +51,6 @@ def index_db(clear_index=True, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet
         max_subprocesses=max_subprocesses,
     )
     index_custom_indexes(clear_index=clear_index, batch_size=batch_size, quiet=quiet)
-    index_resource_relations(clear_index=clear_index, batch_size=batch_size)
 
 
 def index_resources(
@@ -83,7 +83,9 @@ def index_resources(
     )
 
 
-def index_resources_using_multiprocessing(resourceids, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False, max_subprocesses=0):
+def index_resources_using_multiprocessing(
+    resourceids, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False, max_subprocesses=0, callback=None
+):
     try:
         multiprocessing.set_start_method("spawn")
     except:
@@ -111,6 +113,8 @@ def index_resources_using_multiprocessing(resourceids, batch_size=settings.BULK_
     def process_complete_callback(result):
         if quiet is False and bar is not None:
             bar.update(item_id=result)
+        if callback is not None:
+            callback()
 
     def process_error_callback(err):
         import traceback
@@ -147,7 +151,9 @@ def index_resources_using_multiprocessing(resourceids, batch_size=settings.BULK_
         pool.join()
 
 
-def index_resources_using_singleprocessing(resources, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False, title=None):
+def index_resources_using_singleprocessing(
+    resources: Iterable[Resource], batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False, title=None
+):
     datatype_factory = DataTypeFactory()
     node_datatypes = {str(nodeid): datatype for nodeid, datatype in models.Node.objects.values_list("nodeid", "datatype")}
     with se.BulkIndexer(batch_size=batch_size, refresh=True) as doc_indexer:
@@ -160,10 +166,13 @@ def index_resources_using_singleprocessing(resources, batch_size=settings.BULK_I
                 document, terms = resource.get_documents_to_index(
                     fetchTiles=True, datatype_factory=datatype_factory, node_datatypes=node_datatypes
                 )
+                resource.save(index=False)
                 doc_indexer.add(index=RESOURCES_INDEX, id=document["resourceinstanceid"], data=document)
                 for term in terms:
                     term_indexer.add(index=TERMS_INDEX, id=term["_id"], data=term["_source"])
 
+    return os.getpid()
+
 def index_resources_by_type(
     resource_types, clear_index=True, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False, use_multiprocessing=False, max_subprocesses=0
 ):
@@ -219,6 +228,8 @@ def index_resources_by_type(
             )
 
         else:
+            from arches.app.search.search_engine_factory import SearchEngineInstance as _se
+
             resources = Resource.objects.filter(graph_id=str(resource_type))
             index_resources_using_singleprocessing(resources=resources, batch_size=batch_size, quiet=quiet, title=graph_name)
 
@@ -240,20 +251,7 @@ def _index_resource_batch(resourceids):
 
     resources = Resource.objects.filter(resourceinstanceid__in=resourceids)
     batch_size = int(len(resourceids) / 2)
-    datatype_factory = DataTypeFactory()
-    node_datatypes = {str(nodeid): datatype for nodeid, datatype in models.Node.objects.values_list("nodeid", "datatype")}
-
-    with _se.BulkIndexer(batch_size=batch_size, refresh=True, timeout=30, max_retries=10, retry_on_timeout=True) as doc_indexer:
-        with _se.BulkIndexer(batch_size=batch_size, refresh=True, timeout=30, max_retries=10, retry_on_timeout=True) as term_indexer:
-            for resource in resources:
-                document, terms = resource.get_documents_to_index(
-                    fetchTiles=True, datatype_factory=datatype_factory, node_datatypes=node_datatypes
-                )
-                doc_indexer.add(index=RESOURCES_INDEX, id=document["resourceinstanceid"], data=document)
-                for term in terms:
-                    term_indexer.add(index=TERMS_INDEX, id=term["_id"], data=term["_source"])
-
-    return os.getpid()
+    return index_resources_using_singleprocessing(resources, batch_size, quiet=True, se=_se)
 
 
 def index_custom_indexes(index_name=None, clear_index=True, batch_size=settings.BULK_IMPORT_BATCH_SIZE, quiet=False):
@@ -277,59 +275,6 @@ def index_custom_indexes(index_name=None, clear_index=True, batch_size=settings.
         es_index.reindex(clear_index=clear_index, batch_size=batch_size, quiet=quiet)
 
 
-def index_resource_relations(clear_index=True, batch_size=settings.BULK_IMPORT_BATCH_SIZE):
-    """
-    Indexes all resource to resource relation records
-
-    Keyword Arguments:
-    clear_index -- set to True to remove all the resources from the index before the reindexing operation
-    batch_size -- the number of records to index as a group, the larger the number to more memory required
-
-    """
-
-    start = datetime.now()
-    logger.info("Indexing resource to resource relations")
-
-    cursor = connection.cursor()
-    if clear_index:
-        q = Query(se=se)
-        q.delete(index=RESOURCE_RELATIONS_INDEX)
-
-    with se.BulkIndexer(batch_size=batch_size, refresh=True) as resource_relations_indexer:
-        sql = """
-            SELECT resourcexid, notes, datestarted, dateended, relationshiptype, resourceinstanceidfrom, resourceinstancefrom_graphid,
-            resourceinstanceidto, resourceinstanceto_graphid, modified, created, inverserelationshiptype, tileid, nodeid
-            FROM public.resource_x_resource
-        """
-
-        cursor.execute(sql)
-        for resource_relation in cursor.fetchall():
-            doc = {
-                "resourcexid": resource_relation[0],
-                "notes": resource_relation[1],
-                "datestarted": resource_relation[2],
-                "dateended": resource_relation[3],
-                "relationshiptype": resource_relation[4],
-                "resourceinstanceidfrom": resource_relation[5],
-                "resourceinstancefrom_graphid": resource_relation[6],
-                "resourceinstanceidto": resource_relation[7],
-                "resourceinstanceto_graphid": resource_relation[8],
-                "modified": resource_relation[9],
-                "created": resource_relation[10],
-                "inverserelationshiptype": resource_relation[11],
-                "tileid": resource_relation[12],
-                "nodeid": resource_relation[13],
-            }
-            resource_relations_indexer.add(index=RESOURCE_RELATIONS_INDEX, id=doc["resourcexid"], data=doc)
-
-    index_count = se.count(index=RESOURCE_RELATIONS_INDEX)
-    logger.info(
-        "Status: {0}, In Database: {1}, Indexed: {2}, Took: {3} seconds".format(
-            "Passed" if cursor.rowcount == index_count else "Failed", cursor.rowcount, index_count, (datetime.now() - start).seconds
-        )
-    )
-
-
 def index_concepts(clear_index=True, batch_size=settings.BULK_IMPORT_BATCH_SIZE):
     """
     Indxes all concepts from the database
