@@ -227,8 +227,10 @@ def get_createable_resource_types(user):
     user -- the user to check
 
     """
-
-    return get_resource_types_by_perm(user, "models.write_nodegroup")
+    if user_is_resource_editor(user):
+        return get_resource_types_by_perm(user, "models.write_nodegroup")
+    else:
+        return []
 
 
 def get_resource_types_by_perm(user, perms):
@@ -244,7 +246,7 @@ def get_resource_types_by_perm(user, perms):
 
     graphs = set()
     nodegroups = get_nodegroups_by_perm(user, perms)
-    for node in Node.objects.filter(nodegroup__in=nodegroups).select_related("graph"):
+    for node in Node.objects.filter(nodegroup__in=nodegroups).prefetch_related("graph"):
         if node.graph.isresource and str(node.graph_id) != settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID:
             graphs.add(node.graph)
     return list(graphs)
