@@ -16,6 +16,12 @@ You should have received a copy of the GNU Affero General Public License
 along with this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
+import base64
+import io
+
+from django.http import response
+import qrcode
+import pyotp
 import time
 import requests
 from datetime import datetime, timedelta
@@ -31,10 +37,11 @@ from django.utils.translation import ugettext as _
 from django.utils.http import urlencode
 from django.core.mail import EmailMultiAlternatives
 from django.urls import reverse
-from django.contrib.auth import authenticate, login, logout
+from django.contrib.auth import authenticate, login, logout, update_session_auth_hash
 from django.contrib.auth import views as auth_views
 from django.contrib.auth.models import User, Group
 from django.contrib.auth.decorators import login_required
+from django.contrib.sessions.models import Session
 from django.shortcuts import render, redirect
 import django.contrib.auth.password_validation as validation
 from arches import __version__
@@ -73,17 +80,40 @@ class LoginView(View):
 
     def post(self, request):
         # POST request is taken to mean user is logging in
-        auth_attempt_success = None
-        username = request.POST.get("username", None)
-        password = request.POST.get("password", None)
+        username = request.POST.get("username", None)  # user-input value, NOT source of truth
+        password = request.POST.get("password", None)  # user-input value, NOT source of truth
         user = authenticate(username=username, password=password)
         next = request.POST.get("next", reverse("home"))
 
         if user is not None and user.is_active:
-            login(request, user)
-            user.password = ""
-            auth_attempt_success = True
-            return redirect(next)
+            if settings.FORCE_TWO_FACTOR_AUTHENTICATION or settings.ENABLE_TWO_FACTOR_AUTHENTICATION:
+                user_profile = models.UserProfile.objects.get(user=user)
+                user_has_enabled_two_factor_authentication = bool(user_profile.encrypted_mfa_hash)
+
+                if (
+                    settings.FORCE_TWO_FACTOR_AUTHENTICATION or user_has_enabled_two_factor_authentication
+                ):  # user has enabled two-factor authentication
+                    return render(
+                        request,
+                        "two_factor_authentication_login.htm",
+                        {
+                            "username": username,
+                            "password": password,
+                            "next": next,
+                            "email": user.email,
+                            "user_has_enabled_two_factor_authentication": user_has_enabled_two_factor_authentication,
+                        },
+                    )
+                else:
+                    login(request, user)
+                    user.password = ""
+
+                    return redirect(next)
+            else:
+                login(request, user)
+                user.password = ""
+
+                return redirect(next)
 
         return render(
             request, "login.htm", {"auth_failed": True, "next": next, "user_signup_enabled": settings.ENABLE_USER_SIGNUP}, status=401
@@ -258,8 +288,6 @@ class UserProfileView(View):
         password = request.POST.get("password", None)
         user = authenticate(username=username, password=password)
         if user:
-            if hasattr(user, "userprofile") is not True:
-                models.UserProfile.objects.create(user=user)
             userDict = JSONSerializer().serializeToPython(user)
             userDict["password"] = None
             userDict["is_reviewer"] = user_is_resource_reviewer(user)
@@ -276,8 +304,8 @@ class UserProfileView(View):
 @method_decorator(csrf_exempt, name="dispatch")
 class GetClientIdView(View):
     def post(self, request):
-        if settings.MOBILE_OAUTH_CLIENT_ID == "":
-            message = _("Make sure to set your MOBILE_OAUTH_CLIENT_ID in settings.py")
+        if settings.OAUTH_CLIENT_ID == "":
+            message = _("Make sure to set your OAUTH_CLIENT_ID in settings.py")
             response = HttpResponse(message, status=500)
             logger.warning(message)
         else:
@@ -285,7 +313,7 @@ class GetClientIdView(View):
             password = request.POST.get("password", None)
             user = authenticate(username=username, password=password)
             if user:
-                response = JSONResponse({"clientid": settings.MOBILE_OAUTH_CLIENT_ID})
+                response = JSONResponse({"clientid": settings.OAUTH_CLIENT_ID})
             else:
                 response = Http401Response()
         return response
@@ -294,15 +322,15 @@ class GetClientIdView(View):
 @method_decorator(csrf_exempt, name="dispatch")
 class ServerSettingView(View):
     def post(self, request):
-        if settings.MOBILE_OAUTH_CLIENT_ID == "":
-            message = _("Make sure to set your MOBILE_OAUTH_CLIENT_ID in settings.py")
+        if settings.OAUTH_CLIENT_ID == "":
+            message = _("Make sure to set your OAUTH_CLIENT_ID in settings.py")
             logger.warning(message)
 
         username = request.POST.get("username", None)
         password = request.POST.get("password", None)
         user = authenticate(username=username, password=password)
         if user:
-            server_settings = {"version": __version__, "clientid": settings.MOBILE_OAUTH_CLIENT_ID}
+            server_settings = {"version": __version__, "clientid": settings.OAUTH_CLIENT_ID}
             response = JSONResponse(server_settings)
         else:
             response = Http401Response()
@@ -310,6 +338,191 @@ class ServerSettingView(View):
         return response
 
 
+@method_decorator(never_cache, name="dispatch")
+class TwoFactorAuthenticationResetView(View):
+    def get(self, request):
+        queried_email_address = request.GET.get("queried_email_address")
+        return render(
+            request,
+            "two_factor_authentication_reset.htm",
+            {
+                "queried_email_address": queried_email_address,
+            },
+        )
+
+    def post(self, request):
+        email = request.POST.get("email")
+        user = None
+
+        if email:
+            try:
+                user = models.User.objects.get(email=email)
+            except Exception:
+                pass
+
+        if user:
+            try:
+                AES = AESCipher(settings.SECRET_KEY)
+
+                serialized_data = JSONSerializer().serialize({"ts": int(time.time()), "user": user})
+                encrypted_url = urlencode({"link": AES.encrypt(serialized_data)})
+
+                admin_email = settings.ADMINS[0][1] if settings.ADMINS else ""
+                email_context = {
+                    "button_text": _("Update Two-Factor Authentication Settings"),
+                    "link": request.build_absolute_uri(reverse("two-factor-authentication-settings") + "?" + encrypted_url),
+                    "greeting": _("Click on link below to update your two-factor authentication settings."),
+                    "closing": _(
+                        "This link expires in 15 minutes. If you did not request this change, \
+                        contact your Administrator immediately."
+                    ),
+                }
+
+                html_content = render_to_string("email/general_notification.htm", email_context)  # ...
+                text_content = strip_tags(html_content)  # this strips the html, so people will have the text as well.
+
+                # create the email, and attach the HTML version as well.
+                msg = EmailMultiAlternatives(_("Arches Two-Factor Authentication"), text_content, admin_email, [user.email])
+                msg.attach_alternative(html_content, "text/html")
+
+                msg.send()
+            except:
+                raise Exception(_("There has been error sending an email to this address. Please contact your system administrator."))
+
+        return render(
+            request,
+            "two_factor_authentication_reset.htm",
+            {
+                "queried_email_address": email,
+            },
+        )
+
+
+@method_decorator(never_cache, name="dispatch")
+class TwoFactorAuthenticationLoginView(View):
+    def post(self, request):
+        username = request.POST.get("username", None)
+        password = request.POST.get("password", None)
+        user = authenticate(username=username, password=password)
+
+        next = request.POST.get("next", reverse("home"))
+        user_has_enabled_two_factor_authentication = request.POST.get("user-has-enabled-two-factor-authentication", None)
+        two_factor_authentication_string = request.POST.get("two-factor-authentication", None)
+
+        if user is not None and user.is_active and user_has_enabled_two_factor_authentication:
+            user_profile = models.UserProfile.objects.get(user_id=user.pk)
+
+            if user_profile.encrypted_mfa_hash:
+                AES = AESCipher(settings.SECRET_KEY)
+                encrypted_mfa_hash = user_profile.encrypted_mfa_hash[
+                    1 : len(user_profile.encrypted_mfa_hash)
+                ]  # removes outer string values
+                decrypted_mfa_hash = AES.decrypt(encrypted_mfa_hash)
+
+                totp = pyotp.TOTP(decrypted_mfa_hash)
+
+                if totp.verify(two_factor_authentication_string):
+                    login(request, user)
+                    user.password = ""
+
+                    return redirect(next)
+
+        return render(
+            request,
+            "two_factor_authentication_login.htm",
+            {
+                "auth_failed": True,
+                "next": next,
+                "username": username,
+                "password": password,
+                "email": user.email,
+                "user_has_enabled_two_factor_authentication": user_has_enabled_two_factor_authentication,
+            },
+            status=401,
+        )
+
+
+@method_decorator(never_cache, name="dispatch")
+class TwoFactorAuthenticationSettingsView(View):
+    def get(self, request):
+        link = request.GET.get("link", None)
+        AES = AESCipher(settings.SECRET_KEY)
+
+        decrypted_data = JSONDeserializer().deserialize(AES.decrypt(link))
+
+        if datetime.fromtimestamp(decrypted_data["ts"]) + timedelta(minutes=15) >= datetime.fromtimestamp(
+            int(time.time())
+        ):  # if before email expiry
+            user_id = decrypted_data["user"]["id"]
+            user_profile = models.UserProfile.objects.get(user_id=user_id)
+
+            context = {
+                "ENABLE_TWO_FACTOR_AUTHENTICATION": settings.ENABLE_TWO_FACTOR_AUTHENTICATION,
+                "FORCE_TWO_FACTOR_AUTHENTICATION": settings.FORCE_TWO_FACTOR_AUTHENTICATION,
+                "user_has_enabled_two_factor_authentication": bool(user_profile.encrypted_mfa_hash),
+                "user_id": user_id,
+            }
+
+        else:
+            raise Exception("Link Expired")
+
+        return render(request, "two_factor_authentication_settings.htm", context)
+
+    def post(self, request):
+        user_id = request.POST.get("user-id")
+        user = models.User.objects.get(pk=int(user_id))
+        user_profile = models.UserProfile.objects.get(user_id=user_id)
+
+        generate_qr_code = request.POST.get("generate-qr-code-button")
+        generate_manual_key = request.POST.get("generate-manual-key-button")
+        delete_mfa_hash = request.POST.get("delete-mfa-hash-button")
+
+        new_mfa_hash_qr_code = None
+        new_mfa_hash_manual_entry_data = None
+
+        if generate_qr_code or generate_manual_key or delete_mfa_hash:
+            AES = AESCipher(settings.SECRET_KEY)
+
+            if generate_qr_code or generate_manual_key:
+                mfa_hash = pyotp.random_base32()
+                encrypted_mfa_hash = AES.encrypt(mfa_hash)
+                user_profile.encrypted_mfa_hash = encrypted_mfa_hash
+
+                if generate_qr_code:
+                    uri = pyotp.totp.TOTP(mfa_hash).provisioning_uri(user.email, issuer_name=settings.APP_TITLE)
+                    uri_qrcode = qrcode.make(uri)
+
+                    buffer = io.BytesIO()
+                    uri_qrcode.save(buffer)
+
+                    base64_encoded_result_bytes = base64.b64encode(buffer.getvalue())
+                    new_mfa_hash_qr_code = base64_encoded_result_bytes.decode("ascii")
+
+                    buffer.close()
+                elif generate_manual_key:
+                    new_mfa_hash_manual_entry_data = {"new_mfa_hash": mfa_hash, "name": user.email, "issuer_name": settings.APP_TITLE}
+
+            elif delete_mfa_hash and not settings.FORCE_TWO_FACTOR_AUTHENTICATION:
+                user_profile.encrypted_mfa_hash = None
+
+            user_profile.save()
+
+            for session in Session.objects.all():  # logs user out of all sessions
+                if str(session.get_decoded().get("_auth_user_id")) == str(user.id):
+                    session.delete()
+
+        context = {
+            "ENABLE_TWO_FACTOR_AUTHENTICATION": settings.ENABLE_TWO_FACTOR_AUTHENTICATION,
+            "FORCE_TWO_FACTOR_AUTHENTICATION": settings.FORCE_TWO_FACTOR_AUTHENTICATION,
+            "user_has_enabled_two_factor_authentication": bool(user_profile.encrypted_mfa_hash),
+            "new_mfa_hash_qr_code": new_mfa_hash_qr_code,
+            "new_mfa_hash_manual_entry_data": new_mfa_hash_manual_entry_data,
+            "user_id": user_id,
+        }
+
+        return render(request, "two_factor_authentication_settings.htm", context)
+
+
 @method_decorator(csrf_exempt, name="dispatch")
 class Token(View):
     def get(self, request):
@@ -317,7 +530,7 @@ class Token(View):
             data = {
                 "username": request.GET.get("username", None),
                 "password": request.GET.get("password", None),
-                "client_id": settings.MOBILE_OAUTH_CLIENT_ID,
+                "client_id": settings.OAUTH_CLIENT_ID,
                 "grant_type": "password",
             }
             url = request.get_raw_uri().replace(request.path, "").split("?")[0] + reverse("oauth2:token")
