@@ -52,7 +52,6 @@ class BaseManagerView(TemplateView):
             exclude=[
                 "functions",
                 "ontology",
-                "isactive",
                 "isresource",
                 "version",
                 "deploymentdate",
@@ -95,9 +94,11 @@ class MapBaseManagerView(BaseManagerView):
         context = super(MapBaseManagerView, self).get_context_data(**kwargs)
         datatype_factory = DataTypeFactory()
         geom_datatypes = [d.pk for d in models.DDataType.objects.filter(isgeometric=True)]
-        geom_nodes = models.Node.objects.filter(graph__isresource=True, graph__isactive=True, datatype__in=geom_datatypes).exclude(
-            graph__graphid=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID
-        )
+        geom_nodes = models.Node.objects.filter(
+            graph__isresource=True,
+            graph__publication__isnull=False,
+            datatype__in=geom_datatypes,
+        ).exclude(graph__graphid=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
         resource_layers = []
         resource_sources = []
         for node in geom_nodes:
