@@ -27,7 +27,6 @@ from django.utils.translation import ugettext as _
 from django.views.generic import View
 from arches.app.models import models
 from arches.app.models.card import Card
-from arches.app.models.mobile_survey import MobileSurvey
 from arches.app.models.system_settings import settings
 from arches.app.utils.betterJSONSerializer import JSONSerializer, JSONDeserializer
 from arches.app.utils.decorators import group_required
@@ -95,18 +94,7 @@ class UserManagerView(BaseManagerView):
                 }
             )
 
-        user_mobile_surveys = [pxu.mobile_survey for pxu in models.MobileSurveyXUser.objects.filter(user=user)]
-        user_mobile_surveys_by_group = [
-            pxu_x_group.mobile_survey for pxu_x_group in models.MobileSurveyXGroup.objects.filter(group__in=user.groups.all())
-        ]
-
-        for gp in user_mobile_surveys_by_group:
-            if gp not in user_mobile_surveys:
-                user_mobile_surveys.append(gp)
-
-        mobile_surveys, resources = self.get_mobile_survey_resources(user_mobile_surveys)
-
-        return {"identities": identities, "user_surveys": mobile_surveys, "resources": resources}
+        return {"identities": identities}
 
     def get(self, request):
 
@@ -115,8 +103,6 @@ class UserManagerView(BaseManagerView):
                 main_script="views/user-profile-manager",
             )
 
-            user_details = self.get_user_details(request.user)
-
             context["nav"]["icon"] = "fa fa-user"
             context["nav"]["title"] = _("Profile Manager")
             context["nav"]["login"] = True
@@ -126,9 +112,15 @@ class UserManagerView(BaseManagerView):
             }
             context["validation_help"] = validation.password_validators_help_texts()
 
-            context["user_surveys"] = JSONSerializer().serialize(user_details["user_surveys"], sort_keys=False)
-            context["identities"] = JSONSerializer().serialize(user_details["identities"], sort_keys=False)
-            context["resources"] = JSONSerializer().serialize(user_details["resources"], sort_keys=False, exclude=["is_editable"])
+            user_profile = models.UserProfile.objects.get(user_id=request.user.pk)
+
+            context["two_factor_authentication_settings"] = JSONSerializer().serialize(
+                {
+                    "ENABLE_TWO_FACTOR_AUTHENTICATION": settings.ENABLE_TWO_FACTOR_AUTHENTICATION,
+                    "FORCE_TWO_FACTOR_AUTHENTICATION": settings.FORCE_TWO_FACTOR_AUTHENTICATION,
+                    "user_has_enabled_two_factor_authentication": bool(user_profile.encrypted_mfa_hash),
+                }
+            )
 
             return render(request, "views/user-profile-manager.htm", context)
 
@@ -142,9 +134,6 @@ class UserManagerView(BaseManagerView):
                 return JSONResponse(data)
 
         if self.request.user.is_authenticated and self.request.user.username != "anonymous":
-
-            user_details = self.get_user_details(request.user)
-
             context = self.get_context_data(
                 main_script="views/user-profile-manager",
             )
@@ -157,9 +146,6 @@ class UserManagerView(BaseManagerView):
                 "template": "profile-manager-help",
             }
             context["validation_help"] = validation.password_validators_help_texts()
-            context["user_surveys"] = JSONSerializer().serialize(user_details["user_surveys"])
-            context["identities"] = JSONSerializer().serialize(user_details["identities"])
-            context["resources"] = JSONSerializer().serialize(user_details["resources"])
 
             user_info = request.POST.copy()
             user_info["id"] = request.user.id
@@ -184,28 +170,14 @@ class UserManagerView(BaseManagerView):
                 request.user = user
             context["form"] = form
 
-            return render(request, "views/user-profile-manager.htm", context)
+            user_profile = models.UserProfile.objects.get(user_id=request.user.pk)
 
-    def get_mobile_survey_resources(self, mobile_survey_models):
-        graphs = models.GraphModel.objects.filter(isresource=True).exclude(graphid=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
-        resources = []
-        mobile_surveys = []
-        all_ordered_card_ids = []
-
-        for mobile_survey in mobile_survey_models:
-            survey = MobileSurvey.objects.get(id=mobile_survey.id)
-            mobile_survey_dict = survey.serialize()
-            all_ordered_card_ids += mobile_survey_dict["cards"]
-            mobile_surveys.append(mobile_survey_dict)
-
-        active_graphs = {str(card.graph_id) for card in models.CardModel.objects.filter(cardid__in=all_ordered_card_ids)}
-
-        for i, graph in enumerate(graphs):
-            cards = []
-            if i == 0 or str(graph.graphid) in active_graphs:
-                cards = [Card.objects.get(pk=card.cardid) for card in models.CardModel.objects.filter(graph=graph)]
-            resources.append(
-                {"name": graph.name, "id": graph.graphid, "subtitle": graph.subtitle, "iconclass": graph.iconclass, "cards": cards}
+            context["two_factor_authentication_settings"] = JSONSerializer().serialize(
+                {
+                    "ENABLE_TWO_FACTOR_AUTHENTICATION": settings.ENABLE_TWO_FACTOR_AUTHENTICATION,
+                    "FORCE_TWO_FACTOR_AUTHENTICATION": settings.FORCE_TWO_FACTOR_AUTHENTICATION,
+                    "user_has_enabled_two_factor_authentication": bool(user_profile.encrypted_mfa_hash),
+                }
             )
 
-        return mobile_surveys, resources
+            return render(request, "views/user-profile-manager.htm", context)
