@@ -1,13 +1,16 @@
-define(['jquery',
+define([
+    'jquery',
     'knockout',
     'viewmodels/function',
-    'bindings/chosen'],
-function($, ko, FunctionViewModel, chosen) {
+    'bindings/chosen',
+    'templates/views/components/functions/sample-function.htm',
+], function($, ko, FunctionViewModel, chosen, sampleFunctionTemplate) {
     return ko.components.register('views/components/functions/sample-function', {
         viewModel: function(params) {
+             
             FunctionViewModel.apply(this, arguments);
             var nodegroups = {};
-            this.triggering_nodegroups = params.config.triggering_nodegroups;
+            this.triggeringNodegroups = params.config.triggering_nodegroups;
             this.cards = ko.observableArray();
             this.graph.cards.forEach(function(card){
                 this.cards.push(card);
@@ -16,8 +19,6 @@ function($, ko, FunctionViewModel, chosen) {
 
             window.setTimeout(function(){$("select[data-bind^=chosen]").trigger("chosen:updated");}, 300);
         },
-        template: {
-            require: 'text!templates/views/components/functions/sample-function.htm'
-        }
+        template: sampleFunctionTemplate
     });
 });
