@@ -1,8 +1,8 @@
 #!/usr/bin/env bash
 
-# For Ubuntu 18.04 (bionic)
+# For Ubuntu 18.04+
 
-# Use the yes command if you would like to install postgres/postgis, couchdb,
+# Use the yes command if you would like to install postgres/postgis,
 # node/yarn, and elasticsearch.
 # Example:
 # yes | sudo ./ubuntu_setup.sh
@@ -11,20 +11,23 @@ function install_postgres {
   sudo add-apt-repository "deb http://apt.postgresql.org/pub/repos/apt/ $(lsb_release -sc)-pgdg main"
   wget --quiet -O - http://apt.postgresql.org/pub/repos/apt/ACCC4CF8.asc | sudo apt-key add -
   sudo apt-get update
-  sudo apt-get install postgresql-12 postgresql-contrib-12 -y
-  sudo apt-get install postgresql-12-postgis-3 -y
-  sudo -u postgres psql -d postgres -c "ALTER USER postgres with encrypted password 'postgis';"
-  sudo echo "*:*:*:postgres:postgis" >> ~/.pgpass
+  sudo apt-get install postgresql-14 postgresql-contrib-14 -y
+  sudo apt-get install postgresql-14-postgis-3 -y
+  PGPASS=$(openssl rand -base64 14)
+  sudo -u postgres psql -d postgres -c "ALTER USER postgres with encrypted password '$PGPASS';"
+  sudo echo "*:*:*:postgres:$PGPASS" >> ~/.pgpass
   sudo chmod 600 ~/.pgpass
-  sudo chmod 666 /etc/postgresql/12/main/postgresql.conf
-  sudo chmod 666 /etc/postgresql/12/main/pg_hba.conf
-  sudo echo "standard_conforming_strings = off" >> /etc/postgresql/12/main/postgresql.conf
-  sudo echo "listen_addresses = '*'" >> /etc/postgresql/12/main/postgresql.conf
-  sudo echo "#TYPE   DATABASE  USER  CIDR-ADDRESS  METHOD" > /etc/postgresql/12/main/pg_hba.conf
-  sudo echo "local   all       all                 trust" >> /etc/postgresql/12/main/pg_hba.conf
-  sudo echo "host    all       all   127.0.0.1/32  trust" >> /etc/postgresql/12/main/pg_hba.conf
-  sudo echo "host    all       all   ::1/128       trust" >> /etc/postgresql/12/main/pg_hba.conf
-  sudo echo "host    all       all   0.0.0.0/0     md5" >> /etc/postgresql/12/main/pg_hba.conf
+  sudo chmod 666 /etc/postgresql/14/main/postgresql.conf
+  sudo chmod 666 /etc/postgresql/14/main/pg_hba.conf
+  sudo echo "standard_conforming_strings = off" >> /etc/postgresql/14/main/postgresql.conf
+  sudo echo "listen_addresses = '*'" >> /etc/postgresql/14/main/postgresql.conf
+  sudo echo "#TYPE   DATABASE  USER  CIDR-ADDRESS  METHOD" > /etc/postgresql/14/main/pg_hba.conf
+  sudo echo "local   all       all                 trust" >> /etc/postgresql/14/main/pg_hba.conf
+  sudo echo "host    all       all   127.0.0.1/32  trust" >> /etc/postgresql/14/main/pg_hba.conf
+  sudo echo "host    all       all   ::1/128       trust" >> /etc/postgresql/14/main/pg_hba.conf
+  sudo echo "host    all       all   0.0.0.0/0     md5" >> /etc/postgresql/14/main/pg_hba.conf
+  sudo chmod 664 /etc/postgresql/14/main/postgresql.conf
+  sudo chmod 664 /etc/postgresql/14/main/pg_hba.conf
   sudo service postgresql restart
 
   sudo -u postgres createdb -E UTF8 -T template0 --locale=en_US.utf8 template_postgis
@@ -36,13 +39,6 @@ function install_postgres {
   sudo -u postgres psql -d template_postgis -c "GRANT ALL ON spatial_ref_sys TO PUBLIC;"
 }
 
-function install_couchdb {
-  sudo add-apt-repository "deb https://apache.bintray.com/couchdb-deb $(lsb_release -sc) main"
-  wget --quiet -O - https://couchdb.apache.org/repo/bintray-pubkey.asc | sudo apt-key add -
-  sudo apt-get update
-  sudo apt-get install couchdb
-}
-
 function install_yarn {
   wget --quiet -O - https://deb.nodesource.com/setup_16.x | sudo -E bash -
   sudo apt-get update
@@ -57,12 +53,14 @@ function install_yarn {
 function install_elasticsearch {
   sudo apt-get install apt-transport-https
   wget -qO - https://artifacts.elastic.co/GPG-KEY-elasticsearch | sudo apt-key add -
-  sudo sh -c 'echo "deb https://artifacts.elastic.co/packages/7.x/apt stable main" > /etc/apt/sources.list.d/elastic-7.x.list'
+  sudo sh -c 'echo "deb https://artifacts.elastic.co/packages/8.x/apt stable main" > /etc/apt/sources.list.d/elastic-8.x.list'
   sudo apt-get update
   sudo apt-get install elasticsearch
   sudo /bin/systemctl enable elasticsearch.service
   sudo systemctl enable elasticsearch.service
   sudo systemctl start elasticsearch.service
+
+  printf "y\nE1asticSearchforArche5\nE1asticSearchforArche5" | sudo /usr/share/elasticsearch/bin/elasticsearch-reset-password -i -u elastic
 }
 
 function main {
@@ -102,15 +100,6 @@ function main {
     echo Skipping Postgres/PostGIS installation
   fi
 
-  echo -n "Would you like to install and configure couchdb? (y/N)? "
-  read answer
-  if echo "$answer" | grep -iq "^y" ;then
-    echo Yes, Installing CouchDB
-    install_couchdb
-  else
-    echo Skipping CouchDB installation
-  fi
-
   echo -n "Would you like to install and nodejs/npm/and yarn (y/N)? "
   read answer
   if echo "$answer" | grep -iq "^y" ;then
