@@ -119,8 +119,14 @@ class Command(BaseCommand):
             print(f"Not loading records > {options['toobig']}kb")
         if options["quiet"]:
             print("Only announcing timing data")
-        if options["verbosity"]:
+        if options["verbosity"] > 1:
             print("Logging detailed error information: set log level to DEBUG to view messages")
+            print("Verbosity level 2 will log based on the application's LOGGING settings in settings.py")
+            print("Verbosity level 3 will include level 2 logging as well as logging to the console")
+            resp = input("Logging detailed information can slow down the import process.  Continue anyway? (y/n)")
+
+            if "n" in resp.lower():
+                return
 
         if options["strip_search"] and not options["fast"]:
             print("ERROR: stripping fields not exposed to advanced search only works in fast mode")
@@ -131,7 +137,7 @@ class Command(BaseCommand):
 
     def load_resources(self, options):
 
-        self.reader = JsonLdReader(verbosity=options["verbosity"])
+        self.reader = JsonLdReader(verbosity=options["verbosity"], ignore_errors=options["ignore_errors"])
         self.jss = JSONSerializer()
         source = options["source"]
         if options["model"]:
@@ -225,7 +231,7 @@ class Command(BaseCommand):
                         jsdata = fix_js_data(data, jsdata, m)
                         if len(uu) != 36 or uu[8] != "-":
                             # extract uuid from data if filename is not a UUID
-                            uu = jsdata["id"][-36:]
+                            uu = jsdata["@id"][-36:]
                         if jsdata:
                             try:
                                 if options["fast"]:
@@ -387,10 +393,11 @@ def monkey_get_documents_to_index(self, node_info):
                         {
                             "_id": f"{nodeid}{tile.tileid}{index}",
                             "_source": {
-                                "value": term,
+                                "value": term.value,
                                 "nodeid": nodeid,
                                 "nodegroupid": tile.nodegroup_id,
                                 "tileid": tile.tileid,
+                                "language": term.lang,
                                 "resourceinstanceid": tile.resourceinstance_id,
                                 "provisional": False,
                             },
